# This script prepares the data for Fig. 5b and 5c by gathering the yield stress and yield strain over all
# suitable sweeps (excluding some extreme concentrations far from the actual application)

library(rheologyEvaluation)

root_folder = "/data/Evaluation/Rheology/Stress Sweeps"

setwd(root_folder)

# Initialize the yield information variable:
#  - column "material" to indicate the sample type
#  - column "strain": the yield strain
#  - column "tau_Pa": the yield stress, in absolute units
#  - column "Gprime_Pa_0": The low deformation elastic modulus
#  - column "tau_rel": the relative yield stress (i.e. tau_Pa / Gprime_Pa_0)
#  - column "ID": unique measurement identifier. With this and the individual overview files, it is possible
#      to trace back the yield information to given measurements (used mostly for debugging purposes during
#      script development)

yield_info_all_materials = data.frame(material=vector(mode="character",length=0),strain=vector(mode="numeric",length=0),tau_Pa=vector(mode="numeric",length=0),Gprime_Pa=vector(mode="numeric",length=0),Gprime_Pa_0=vector(mode="numeric",length=0),tau_rel=vector(mode="numeric",length=0),ID=vector(mode="character",length=0))

# Collect the yield point info from the different datasets available. First, the backbone variation dataset

load(file="backbone_variation/stress_sweeps_backbone_variation.rda")

stress_sweeps_backbone_variation$Gprime_normalization = overview_backbone_variation$Gprime[stress_sweeps_backbone_variation$overview_index]

stress_sweeps_backbone_variation$tau_rel = stress_sweeps_backbone_variation$tau_Pa/stress_sweeps_backbone_variation$Gprime_normalization

all_sweeps=data.frame(
    rda_file=vector(mode="character",length=0),
    overview_index=vector(mode="numeric",length=0),
    ID = vector(mode="character",length=0),
    polymer_conc_mgmL=vector(mode="numeric",length=0),
    Material=vector(mode="character",length=0),
    Geometry=vector(mode="character",length=0),
    tau_Pa=vector(mode="numeric",length=0),
    Gamma_in_percent=vector(mode="numeric",length=0),
    Gprime_Pa=vector(mode="numeric",length=0),
    Gprimeprime_Pa=vector(mode="numeric",length=0))

for(ind in unique(stress_sweeps_backbone_variation$overview_index))
{
    current_data = stress_sweeps_backbone_variation[stress_sweeps_backbone_variation$overview_index==ind,]
    Gprime_Pa_0=current_data$Gprime_normalization[1]
    
    material = paste("EPI - ",current_data[1,"Material"],sep="")
    
    ID = paste("backbone_variation",ind,sep="_")
    current_data$logGamma = log(current_data$Gamma_in_percent)
    current_data$logGprime_Pa = log(current_data$Gprime_Pa)
    current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
    
    yield_strain=exp(evaluateYield(current_data,
    Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
    
    yield_tau_info=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated=c("tau_rel","tau_Pa"))
    
    yield_tau_rel=yield_tau_info[["tau_rel"]]
    yield_tau_Pa=yield_tau_info[["tau_Pa"]]
    
    yield_info_all_materials=rbind(yield_info_all_materials,
        data.frame(material=material,
            strain=yield_strain,tau_Pa=yield_tau_Pa,Gprime_Pa=yield_tau_info[["Gprime_Pa"]],
            Gprime_Pa_0=Gprime_Pa_0,tau_rel=yield_tau_rel,ID=ID))
    
    current_data_to_insert=data.frame(
        rda_file="backbone_variation/stress_sweeps_backbone_variation.rda",
        overview_index=ind,
        ID = ID,
        polymer_conc_mgmL=current_data$polymer_conc_mgmL,
        Material=material,
        Geometry=current_data$Geometry,
        tau_Pa=current_data$tau_Pa,
        Gamma_in_percent=current_data$Gamma_in_percent,
        Gprime_Pa=current_data$Gprime_Pa,
        Gprimeprime_Pa=current_data$Gprimeprime_Pa)
        
    all_sweeps=rbind(all_sweeps, current_data_to_insert)
    
}

# Next cultisphere
load("cultisphere/stress_sweeps_cultisphere.rda")

files_for_yield_evaluation = unique(stress_sweeps_cultisphere$file)[2:5] # The first measurement concerns the same
# sample as the second one, but has less points (initial trial), so discard and keep only the more precise
# second measurement


for(theFile in files_for_yield_evaluation)
{
    current_data = stress_sweeps_cultisphere[stress_sweeps_cultisphere$file==theFile,]
    Gprime_Pa_0 = current_data$Gprime_normalized[1]*current_data$Gprime_Pa[1] # reconstruct the normalization Gprime
    
    current_data$logGamma = log(current_data$Gamma_in_percent)
    current_data$logGprime_Pa = log(current_data$Gprime_Pa)
    current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
    
    yield_strain_cultisphere=exp(evaluateYield(current_data,
    Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
    
    yield_info=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated=c("tau_Pa","tau_normalized"))
    
    yield_tau_rel_cultisphere=yield_info[["tau_normalized"]]
    yield_tau_Pa=yield_info[["tau_Pa"]]
    
    ID = paste("cultisphere",theFile,sep="_")
    material = "cultisphere"
    
    yield_info_all_materials=rbind(yield_info_all_materials,
    data.frame(material="cultisphere",
    strain=yield_strain_cultisphere,tau_Pa=yield_tau_Pa,Gprime_Pa=yield_info[["Gprime_Pa"]],
    Gprime_Pa_0=Gprime_Pa_0,tau_rel=yield_tau_rel_cultisphere,ID=ID))
    
    current_data_to_insert=data.frame(
        rda_file="cultisphere/stress_sweeps_cultisphere.rda",
        overview_index=ind,
        ID = ID,
        polymer_conc_mgmL=current_data$polymer_conc_mgmL,
        Material=material,
        Geometry=current_data$Geometry,
        tau_Pa=current_data$tau_Pa,
        Gamma_in_percent=current_data$Gamma_in_percent,
        Gprime_Pa=current_data$Gprime_Pa,
        Gprimeprime_Pa=current_data$Gprimeprime_Pa)
        
    all_sweeps=rbind(all_sweeps, current_data_to_insert)

    
    
    
    
}


# EPI sweeps, general dataset
load("EPI/stress_sweeps_EPI_all.rda")

# We collected EPI sweeps in quite extreme variations of concentrations. Focus here on the more relevant ones around 20-30 mg/mL.

to_use_EPI = stress_sweeps_EPI_all[ stress_sweeps_EPI_all$polymer_conc_mgmL>= 20 & stress_sweeps_EPI_all$polymer_conc_mgmL<=30 ,]

for(theID in unique(to_use_EPI$ID))
{
    
    current_data = to_use_EPI[to_use_EPI$ID==theID,]
    Gprime_Pa_0=current_data$Gprime_Pa_0[1]
    
    material = paste("EPI - CMC",sep="")
    
    ID = paste("EPI_all",theID,sep="_")
    
    current_data$logGamma = log(current_data$Gamma_in_percent)
    current_data$logGprime_Pa = log(current_data$Gprime_Pa)
    current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
    
    yield_strain=exp(evaluateYield(current_data,
    Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
    
    current_data$tau_rel = current_data$tau_Pa/Gprime_Pa_0
    
    yield_info=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated=c("tau_Pa","tau_rel"))
    
    yield_tau_rel=yield_info[["tau_rel"]]
    yield_tau_Pa=yield_info[["tau_Pa"]]
    
    
    yield_info_all_materials=rbind(yield_info_all_materials,
    data.frame(material=material,
    strain=yield_strain,tau_Pa=yield_tau_Pa,Gprime_Pa=yield_info[["Gprime_Pa"]],
    Gprime_Pa_0=Gprime_Pa_0,tau_rel=yield_tau_rel,ID=ID))
    
    
    
    current_data_to_insert=data.frame(
        rda_file="EPI/stress_sweeps_EPI_all.rda",
        overview_index=ind,
        ID = ID,
        polymer_conc_mgmL=current_data$polymer_conc_mgmL,
        Material=material,
        Geometry=current_data$Geometry,
        tau_Pa=current_data$tau_Pa,
        Gamma_in_percent=current_data$Gamma_in_percent,
        Gprime_Pa=current_data$Gprime_Pa,
        Gprimeprime_Pa=current_data$Gprimeprime_Pa)
        
    all_sweeps=rbind(all_sweeps, current_data_to_insert)
    
    
    
    
    
}


# Sephacryl S200

load("Sephacryl_S200/stress_sweeps_sephacryl_S200.rda")


for(theFile in unique(stress_sweeps_sephacryl_S200$file))
{
    
    current_data = stress_sweeps_sephacryl_S200[stress_sweeps_sephacryl_S200$file==theFile,]
    
    # The very diluted suspensions should not be considered, there is sedimentation and very unreliable measurements
    
    if(max(current_data$Gprime_Pa)>1)
    {
        
        material = paste("Sephacryl S200",sep="")
        
        ID = paste("Sephacryl",theFile,sep="_")
        
        Gprime_Pa_0 = current_data$Gprime_Pa[1] # Low strain limit Gprime: first measured value
        
        current_data$logGamma = log(current_data$Gamma_in_percent)
        current_data$logGprime_Pa = log(current_data$Gprime_Pa)
        current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
        
        yield_strain=exp(evaluateYield(current_data,
        Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
        
        current_data$tau_rel = current_data$tau_Pa/Gprime_Pa_0
        
        yield_info=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated=c("tau_rel","tau_Pa"))
        
        yield_tau_rel=yield_info[["tau_rel"]]
        yield_tau_Pa = yield_info[["tau_Pa"]]
        
        
        
        # Check whether this estimate is within a factor of 2x from the highest measured strain
        if(any(current_data$Gprimeprime_Pa>current_data$Gprime_Pa))
        {
            highest_deformation_in_elastic_regime = current_data$Gamma_in_percent[which.min(current_data$tau_rel+2*(as.numeric(!(current_data$Gprimeprime_Pa>current_data$Gprime_Pa))*max(current_data$tau_rel)))-1]/100
            
            
            
            if(yield_strain<3*highest_deformation_in_elastic_regime)
            {
                
                
                yield_info_all_materials=rbind(yield_info_all_materials,
                data.frame(material=material,
                strain=yield_strain,tau_Pa=yield_tau_Pa,Gprime_Pa=yield_info[["Gprime_Pa"]],
                Gprime_Pa_0=Gprime_Pa_0,tau_rel=yield_tau_rel,ID=ID))
                
                
            } else
            {
                
                
                # Due to the brittle nature of this material, the chuck turns freely and generates enormous (but artificially large) strains just after yielding. If the yield strain by interpolation is more than 3x larger than the highest measured yield strain, it is better to extrapolate from the solid part
                
                highest_ind=which.min(current_data$tau_rel+2*(as.numeric(!(current_data$Gprimeprime_Pa>current_data$Gprime_Pa))*max(current_data$tau_rel)))-1
                
                second_highest_ind=which.min(current_data$tau_rel+2*(as.numeric(!(current_data$Gprimeprime_Pa>current_data$Gprime_Pa))*max(current_data$tau_rel)))-2
                
                logGamma=log(current_data$Gamma_in_percent)[c(second_highest_ind,highest_ind)]
                logGprime_Pa=log(current_data$Gprime_Pa)[c(second_highest_ind,highest_ind)]
                tau_rel_support = current_data$tau_rel[c(second_highest_ind,highest_ind)]
                logGamma_yield=logGamma[2]+(logGamma[2]-logGamma[1])/(tau_rel_support[2]-tau_rel_support[1])*(yield_tau_rel-tau_rel_support[1])
                logGprime_Pa_yield=logGprime_Pa[2]+(logGprime_Pa[2]-logGprime_Pa[1])/(tau_rel_support[2]-tau_rel_support[1])*(yield_tau_rel-tau_rel_support[1])
                
                yield_info_all_materials=rbind(yield_info_all_materials,
                data.frame(material=material,strain=exp(logGamma_yield)/100,tau_rel=yield_tau_rel,tau_Pa=yield_tau_Pa,Gprime_Pa=exp(logGprime_Pa_yield),
                Gprime_Pa_0=Gprime_Pa_0,ID=ID))
            }
        
        current_data_to_insert=data.frame(
            rda_file="Sephacryl_S200/stress_sweeps_sephacryl_S200.rda",
            overview_index=ind,
            ID = ID,
            polymer_conc_mgmL=current_data$polymer_conc_mgmL,
            Material=material,
            Geometry=current_data$Geometry,
            tau_Pa=current_data$tau_Pa,
            Gamma_in_percent=current_data$Gamma_in_percent,
            Gprime_Pa=current_data$Gprime_Pa,
            Gprimeprime_Pa=current_data$Gprimeprime_Pa)
            
        all_sweeps=rbind(all_sweeps, current_data_to_insert)
        
        }
    }
    
    
    
   
    
    
    
    
}


# Juvederm: There are three trials in this file, analyze them one-by-one



load("Juvederm_Voluma/stress_sweeps_juvederm.rda")


current_start=1


segments=c(35,34,33)


for(ind in 1:length(segments))
{
    
    current_data =stress_sweeps_juvederm[(current_start):(current_start+segments[ind]-1),]
    
    G0 = mean(current_data$Gprime_Pa[current_data$tau_Pa<5])
    current_data$tau_rel = current_data$tau_Pa/G0
    Gprime_Pa_0 = G0
    
    current_start=current_start+segments[ind]
    material = paste("Juvederm",sep="")
    
    ID = paste("Juverderm",ind,sep="_")
    
    current_data$logGamma = log(current_data$Gamma_in_percent)
    current_data$logGprime_Pa = log(current_data$Gprime_Pa)
    current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
    
    yield_strain=exp(evaluateYield(current_data,
    Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
    
    current_data$tau_rel = current_data$tau_Pa/current_data$Gprime_Pa[1]
    
    yield_info=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated=c("tau_rel","tau_Pa"))
    
    
    yield_tau_rel=yield_info[["tau_rel"]]
    yield_tau_Pa = yield_info[["tau_Pa"]]
    
    
    yield_info_all_materials=rbind(yield_info_all_materials,
    data.frame(material=material,strain=yield_strain,tau_rel=yield_tau_rel,
    tau_Pa=yield_tau_Pa,Gprime_Pa=yield_info[["Gprime_Pa"]],Gprime_Pa_0=Gprime_Pa_0,ID=ID))
    
    
    current_data_to_insert=data.frame(
        rda_file="Juvederm_Voluma/stress_sweeps_juvederm.rda",
        overview_index=ind,
        ID = ID,
        polymer_conc_mgmL=current_data$polymer_conc_mgmL,
        Material=material,
        Geometry=current_data$Geometry,
        tau_Pa=current_data$tau_Pa,
        Gamma_in_percent=current_data$Gamma_in_percent,
        Gprime_Pa=current_data$Gprime_Pa,
        Gprimeprime_Pa=current_data$Gprimeprime_Pa)
        
    all_sweeps=rbind(all_sweeps, current_data_to_insert)
    
    
    
    
}


# Dataset with the variation of the particle geometry

load("/data/Evaluation/For Supplementaries/Supplementary 9 Material comparison/stress_sweeps_comparison.rda")


# Avoid duplicates between the EPI all dataset and the stress_sweeps_comparison, since the
# EPI sweeps in stress_sweeps_comparison are already included
# in the EPI/stress_sweeps_EPI_all.rda file

stress_sweeps_comparison$ID=paste("comparison",stress_sweeps_comparison$overview_index,sep="_")


stress_sweeps_comparison=stress_sweeps_comparison[!(stress_sweeps_comparison$ID %in% unique(stress_sweeps_EPI_all$ID)),]

for(theFile in unique(stress_sweeps_comparison$file))
{
    
    current_data = stress_sweeps_comparison[stress_sweeps_comparison$file==theFile,]
    
    material = current_data$Material[1]
    if(material=="EPI") {material= "EPI - CMC" }
    
    Gprime_Pa_0 = current_data$Gprime_Pa[1]
    
    ID=paste("comparison",theFile,sep="_")
    
    current_data$logGamma = log(current_data$Gamma_in_percent)
    current_data$logGprime_Pa = log(current_data$Gprime_Pa)
    current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
    
    yield_strain=exp(evaluateYield(current_data,
    Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
    
    current_data$tau_rel = current_data$tau_Pa/Gprime_Pa_0
    
    yield_info=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated=c("tau_rel","tau_Pa"))
    
    yield_tau_rel=yield_info[["tau_rel"]]
    yield_tau_Pa=yield_info[["tau_Pa"]]
    
    yield_info_all_materials=rbind(yield_info_all_materials,
    data.frame(material=material,strain=yield_strain,tau_rel=yield_tau_rel,ID=ID,tau_Pa=yield_tau_Pa,
    Gprime_Pa=yield_info[["Gprime_Pa"]],Gprime_Pa_0=Gprime_Pa_0))
    
    current_data_to_insert=data.frame(
        rda_file="/data/Evaluation/For Supplementaries/Supplementary 9 Material comparison/stress_sweeps_comparison.rda",
        overview_index=ind,
        ID = ID,
        polymer_conc_mgmL=current_data$polymer_conc_mgmL,
        Material=material,
        Geometry=current_data$Geometry,
        tau_Pa=current_data$tau_Pa,
        Gamma_in_percent=current_data$Gamma_in_percent,
        Gprime_Pa=current_data$Gprime_Pa,
        Gprimeprime_Pa=current_data$Gprimeprime_Pa)
        
    all_sweeps=rbind(all_sweeps, current_data_to_insert)
    
    
   
    
    
    
    
}

setwd("/results/Evaluation/Rheology/Stress Sweeps")


sweeps_all_materials=all_sweeps






save(file="yield_info_all_materials.rda",list=c("yield_info_all_materials","root_folder","sweeps_all_materials"))