# Figure 2b shows the simulated shear strain response a frictional spherical microgel suspension. This scripts plots the figure from stored stimulation data (R data file "overview_simulation_jumps_corrected.rda")

# First load the overview_simulation_jumps_corrected.rda file

load("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected.rda")


# Start a pdf device to store the final graphics
pdf("fig_2b.pdf")

# ============= Begin evaluation ===================================

# Use the G' and G'' evaluation corrected for spheres leaving and entering the measurement area

overview_simulation$Gprime_Pa[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]=
overview_simulation$Gprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]

overview_simulation$Gprimeprime_Pa[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]=
overview_simulation$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]



# Aggregate to have average curves

to_aggregate=c("Gprime_Pa","Gprimeprime_Pa","Stress","actual_remove_link_fraction")

by = c("Friction_coefficient","Strain_amplitude","Sample_type","packing_fraction","interface_reenforcement_central","Young_modulus_spheres","remove_link_fraction")

# We restrict ourselves to 5 cut lines to have always similar particles (or no cut line at all for bulk)

use=overview_simulation$cut_lines %in% c(0,5)



# Actual aggregation
overview_agg=aggregate(overview_simulation[,to_aggregate],by=overview_simulation[,by],FUN=mean,na.rm=TRUE)
overview_agg_sd=aggregate(overview_simulation[,to_aggregate],by=overview_simulation[,by],FUN=sd,na.rm=TRUE)


# For sample size reporting
not_NA = apply(overview_simulation[,to_aggregate],1,function(x){all(! is.na(x))})
overview_agg_N=aggregate(overview_simulation[not_NA,to_aggregate],by=overview_simulation[not_NA,by],FUN=length)


# Can be used to check that the removal fraction was as intended. This is generally the case for removal fractions below 0.5, higher fractions cannot always be achieved because it would break the particles into several pieces
removal_agg = aggregate(actual_remove_link_fraction ~ remove_link_fraction + Friction_coefficient +  Sample_type +  packing_fraction + interface_reenforcement_central+ Young_modulus_spheres, overview_agg, FUN=mean )

# To visualize, type
# plot(actual_remove_link_fraction ~ remove_link_fraction, removal_agg)
# at the R command line (this is a supplementary check not presented in the manuscript)


# These are our main, nominal model parameters (the default values in the Python library)
common_conditions=
overview_agg$packing_fraction==1.5 &
overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres==10000


# Here, we are specifically interested in frictional spherical suspensions
sphere_sel =
common_conditions&
overview_agg$Friction_coefficient==0.01 &
overview_agg$Sample_type=="uncrosslinked"





# Estimate the yield strain
for_yield_strain=overview_agg[common_conditions & overview_agg$Friction_coefficient %in% c(0,0.01),]

# We should do this for every unique condition
unique_conditions=aggregate(for_yield_strain$Gprime_Pa,by=for_yield_strain[,c("Friction_coefficient","Sample_type","remove_link_fraction")],FUN=mean)

unique_conditions$yield_strain=NA

for(ind in 1:length(unique_conditions$yield_strain))
{
    current_data =for_yield_strain[for_yield_strain$Friction_coefficient==unique_conditions$Friction_coefficient[ind] & for_yield_strain$Sample_type==unique_conditions$Sample_type[ind] &
    for_yield_strain$remove_link_fraction==unique_conditions$remove_link_fraction[ind],]
    
    current_data = current_data[order(current_data$Strain_amplitude,decreasing=TRUE),]
    
    
    # From the largest strain, find first strain where Gprime is equal to or larger than Gprimeprime
    
    ind_first_solid = min(which(current_data$Gprime_Pa>current_data$Gprimeprime_Pa))
    
    if(ind_first_solid==1)
    {
        unique_conditions$yield_strain[ind]=current_data$Strain_amplitude[ind_first_solid]
        
    }
    if(ind_first_solid==Inf)
    {
        unique_conditions$yield_strain[ind]=NA
    }
    if(ind_first_solid>1)
    {
        difference_solid=current_data$Gprime_Pa[ind_first_solid]-current_data$Gprimeprime_Pa[ind_first_solid]
        difference_liquid=current_data$Gprime_Pa[ind_first_solid-1]-current_data$Gprimeprime_Pa[ind_first_solid-1]
        
        difference_strain_amplitude = current_data$Strain_amplitude[ind_first_solid]-current_data$Strain_amplitude[ind_first_solid-1]
        
        # linear interpolation
        
        unique_conditions$yield_strain[ind]=current_data$Strain_amplitude[ind_first_solid-1]-difference_liquid/(difference_solid-difference_liquid)*difference_strain_amplitude
        
        
        
    }
}


# Common graphical parameters

ylim=c(1,2500)
xlim=c(0.1,100)
cex=2
pch=21




# Control: Non-crosslinked spheres with friction


to_plot = overview_agg[sphere_sel,]



to_plot_sd = overview_agg_sd[sphere_sel,]

# so keep them only on selected strains
to_plot_sd$Gprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0
to_plot_sd$Gprimeprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0


# First plot G'
plot(to_plot$Strain_amplitude*100,to_plot$Gprime_Pa,ylab="G', G''[Pa]",xlab="Strain [%]",log="x",ylim=ylim,xlim=xlim,cex=cex,pch=pch,bg="black",main="2b) Spherical",type="b")

# Add G''
lines(to_plot$Strain_amplitude*100,to_plot$Gprimeprime_Pa,pch=pch,bg="white",cex=cex,type="b")


# Standard deviations: We can't plot them on all points, otherwise the graph becomes unreadable
# So reported them for strains at integral powers of 10

for_standard_deviation = to_plot[to_plot$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1),]
for_standard_deviation_sd = to_plot_sd[to_plot$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1),]

# Add the standard deviations for G'
arrows(x0=for_standard_deviation$Strain_amplitude*100,y0=for_standard_deviation$Gprime_Pa-for_standard_deviation_sd$Gprime_Pa,
    x1=for_standard_deviation$Strain_amplitude*100,y1=for_standard_deviation$Gprime_Pa+for_standard_deviation_sd$Gprime_Pa,angle=90,code=3)

# Add the standard deviations for G''
arrows(x0=for_standard_deviation$Strain_amplitude*100,y0=for_standard_deviation$Gprimeprime_Pa-for_standard_deviation_sd$Gprimeprime_Pa,
x1=for_standard_deviation$Strain_amplitude*100,y1=for_standard_deviation$Gprimeprime_Pa+for_standard_deviation_sd$Gprimeprime_Pa,angle=90,code=3)


# Yield strain
cat("Yield strain [%]: ")
cat(100*unique_conditions$yield_strain[unique_conditions$Friction_coefficient==0.01 & unique_conditions$Sample_type=="uncrosslinked" ])
cat("\n")


# Sample size reporting
cat("\n\nStatistical reporting Item 1")
cat("\nTotal N simulations: ")
cat(sum(overview_agg_N[sphere_sel,"Gprime_Pa"]))

cat("\nMinimal N simulations per strain: ")
cat(min(overview_agg_N[sphere_sel,"Gprime_Pa"]))

cat("\nMaximal N simulations per strain ")
cat(max(overview_agg_N[sphere_sel,"Gprime_Pa"]))
cat("\n")

dev.off()