# Fig. 2g shows a matrix linking different physical parameters to features of the typical shear strain response of the various microgel suspensions. It displays stored simulation data from which random samples have been redrawn for bootstrapping (in "overview_simulation_jumps_corrected_bootstrap.rda")

# libraries used
# Particle shear simulation: functions for analyzing simulation data
library(particleShearEvaluation)
# For the labelling
library(plot.counts)

# This script needs overview_simulation_jumps_corrected.rda 

load("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda")

# Start a pdf device for registering the figure
pdf("fig_2g.pdf")


# Variable to hold the P-values from normality test (Shapiro-Wilks)

normality_pvals = matrix(nrow=5, ncol=5)

colnames(normality_pvals)=c("G' low plateau","Softening strain","Strain on soft plateau","G' on soft plateau","Yield strain")

rownames(normality_pvals)=c("Young modulus","Packing density","Friction coefficient","Porosity","Shape")



# The idea of this scipt is that for all the variables under study (Young modulus, packing density, friction coefficient, porosity and shape) comparative scenarios are analysed via regression. Sometimes there are only two different cases, but still proceed with linear regression as it then becomes equivalent to direct comparative testing, and keeps the analysis unique

# We study the influence of these model parameters on the G' on the low plateau, the softening strain, the strain on the soft plateau, G' on the soft plateau, and the yield strain.

# In the manuscript, we do not report the effect on the strain on the soft plateau, in the interest of conciseness, but the data here shows that it would be difficult to change this parameter if one were interested in doing so because despite an overall large number of simulation, we see no effect on the strain on soft plateau

# Bootstrapping is necessary for the cases where the values tested are evaluated from full curves: Softening strain, Strain on soft plateau,G' on soft plateau, Yield strain



# First row in Fig. 2g. Influence of the Young modulus on the curve characteristics
cat("Evaluation of the influence of the Young modulus\n")


# Reference select: The general reference is the irregular, porous particles (link removal fraction
# 0.4), at a packing density of 1.5 (that is quite compressed), with a friction coefficient 0.01 (for a not very slippery hydrogel), Young's modulus of the constituent spheres 10000 (stiffer than the final material). 

# This selects the averaged curves
reference_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4

# The unique conditions variable lists the simulated combinations of physical parameters
reference_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4

# and this selects the entire set of simulations corresponding to the physical conditions
reference_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001

# Nominal evaluation of the characteristic features of the reference curve
# Type help(evaluate_stress_curve) for details on the evaluation
reference_evaluation=evaluate_stress_curve(overview_agg$Strain_amplitude[reference_select],overview_agg$Gprime_Pa[reference_select],overview_agg$Gprimeprime_Pa[reference_select])



# Selection for linear regression: Include additional simulations 
# where only the Young modulus of the constituent spheres is different from the reference value

# Selection at the aggregated level
comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(12500) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4

# Selection of the simulations at the lowest strain values
# (0.001) for the low-strain G' plateau value
comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(12500) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001

# and at the level of the unique conditions
comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(12500) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4

comparison_evaluation=evaluate_stress_curve(overview_agg$Strain_amplitude[comparison_select],overview_agg$Gprime_Pa[comparison_select],overview_agg$Gprimeprime_Pa[comparison_select])

# enlargen the spectrum of Young modulus values
other_side_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(7500,1000,1e5) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001

other_side_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(7500,1e3,1e5) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4


all_select=comparison_select_unique | reference_select_unique | other_side_select_unique



pvals_Young=vector(mode="numeric",length=5)
names(pvals_Young)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")


# For the G' plateau value at low strain, we simply take the value of the simulated G' at the lowest simulated strain (0.001). In this case, there is no need for bootstrapping.

# First, we tried to use a standard linear model. The residues are however not normally distributed,
# but roughly proportional to the expected value. So we had to switch to general linear models

# This was our linear model command
#linmod=lm(Gprime_Pa ~ Young_modulus_spheres,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,])

# and this is the glm variant dealing with the inconstant variance
linmod=glm(Gprime_Pa ~ Young_modulus_spheres,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,],family=quasi(link = "identity", variance = "mu^2"))

# Get the P-value
pvals_Young["low_strain_plateau"]=coefficients(summary(linmod))["Young_modulus_spheres","Pr(>|t|)"]

# Below are R commands for reporting statistics

cat("\n\tStatistical reporting 2G-E1 (Influence of Young modulus on the low-deformation G'): Item 5")

# Group sizes for the general linear regression
n_Young=aggregate(Gprime_Pa ~ Young_modulus_spheres,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,],FUN=length)
colnames(n_Young)[2]="n"
cat("\n\t\tn per group: ")
n_Young
cat("\n\t\tN total simulations: ")
sum(n_Young$n)


# Shapiro-Wilks on the residuals
normality_pvals["Young modulus","G' low plateau"]=shapiro.test(resid(linmod))[["p.value"]]
cat("\n\t\tNormality testing pre-mitigation (linear model)")
shapiro.test(resid(lm(Gprime_Pa ~ Young_modulus_spheres,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,])))[["p.value"]]
cat("\n\t\tNormality testing post-mitigation (general linear model with variance proportional to mu^2")
normality_pvals["Young modulus","G' low plateau"]
# Confidence interval for the association (basically, the proportionality constant relating the change in Young modulus to the expected change in G' value on the low strain plateau )
cat("\n\t\tConfidence interval for the slope coefficient between low-deformation G' and sphere Young modulus")
suppressMessages(confint(linmod,"Young_modulus_spheres"))

# The GLM doesn't provide an R^2 directly, so we have to calculate it manually
s=summary(linmod)

deviance0 = s$null.deviance
# If we do the complete regression, the deviance becomes smaller
deviance_residual = s$deviance


cat("\n\t\tt value:")
coefficients(summary(linmod))["Young_modulus_spheres","t value"]

cat("\n\t\tDegrees of freedom:")
summary(linmod)[["df.residual"]]

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\n\t\tEffect size measure: Adjusted R2")
1 - (deviance_residual/deviance0) * s$df.null/s$df.residual

cat("\n\t\tP-value (before multiple testing adjustment")
pvals_Young["low_strain_plateau"]


# This is the bootstrapping evaluation (Nisbet, R., Miner, G. & Yale, K. in Handbook of Statistical Analysis and Data Mining Applications (Second Edition)   (eds Robert Nisbet, Gary Miner, & Ken Yale)  215-233 (Academic Press, 2018)). The x values are the selected Young modulus values; the y-values are the characteristic mid-softening strain values which were previously obtained by using sub-sampling (20% chance of inclusion into each sample, 5 samples with possible repetition) for each strain value. From the regression of the 5 bootstrapping mid-softening strain for each of the Young modulus values, a t-value is calculated by linear regression. This is repeated across the columns of bootstrap_draws_mid_softening_strain, always bundled by 5 to have 5 values per Young modulus. This yields a set of t-values (here, 500 t-values), from which an average F value is calculated as the mean of the squares t^2, associated with 1 degree of freedom in the numerator and for the 5 Young modulus values used here, 5x5-2=23 degrees of freedom in the denominator. From this, the p-value is calculated. See also the help entry of linear_regression_p_bootstrap in the installed library particleShearSimulation, accessible by help(linear_regression_p_bootstrap)
res=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])

# Store the P-value associated with the F-statistics
pvals_Young["softening_strain"]=res
# Additional statistical information is available through the attributes of res (accessible by attributes(res)).
normality_pvals["Young modulus","Softening strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-E2 (Influence of Young modulus on the softening strain): Item 6")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction==1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_spheres%in%c(1e3,7.5e3,1e4,1.25e4,1e5) & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the sphere Young modulus and the softening strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_Young["softening_strain"]




# Same approach as above, linking this time the soft_plateau strain to the Young modulus
res=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])
pvals_Young["soft_plateau_strain"]=res
normality_pvals["Young modulus","Strain on soft plateau"]=attr(res,"p_shapiro")
# For simplicity, this is not reported in Fig. 2G, so we don't report all the associated statistics here







# For the soft plateau G' value, we tried first normal linear regression (with bootstrapping) as above, via the command:
res_lm=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])

# but the residues are strongly non-normal so we use a glm with error proportional to value (variance proportional to value squared
# For this, we use general_linear_regression_p_bootstrap, which works similarly to linear_regression_p_bootstrap, but allows variable variance of the residues (here, chosen proportional to the square of the expected value, corresponding to the anticipated situation where the G' value, but also it's standard deviation, are proportional to the Young modulus)
res=general_linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,],family=quasi(link = "identity", variance = "mu^2"))
pvals_Young["soft_plateau_Gprime"]=res
normality_pvals["Young modulus","G' on soft plateau"]=attr(res,"p_shapiro")


cat("\n\tReporting 2G-E3 (Influence of Young modulus on the plateau G'): Item 7")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction==1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_spheres%in%c(1e3,7.5e3,1e4,1.25e4,1e5) & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model without non-normality mitigation)")
attr(res_lm,"p_shapiro")
cat("\n\t\tNormality testing (general linear model with variance proportional to mu^2 for mitigation of non-normality)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the sphere Young modulus and the softening strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_Young["soft_plateau_Gprime"]




# For the yield strain we again use standard linear regression with bootstrapping
res=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_yield_strain[all_select,])
pvals_Young["yield"]=res
normality_pvals["Young modulus","Yield strain"]=attr(res,"p_shapiro")
cat("\n\tReporting 2G-E4 (Influence of Young modulus on the yield strain): Item 8")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction==1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_spheres%in%c(1e3,7.5e3,1e4,1.25e4,1e5) & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the sphere Young modulus and the yield strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_Young["yield"]




# Change in packing density ==============================================================
# We use here the same method as above, with linear regression with bootstrapping for the compound values "softening_strain","soft_plateau_strain","soft_plateau_Gprime",and "yield", and regular regression for the low strain plateau.

# For detailed comments see above, this is analogous, we are looking at packing density rather than Young modulus
cat("Evaluation of the influence of packing density\n")

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(2) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4



comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(2) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(2) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4




other_side_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001

other_side_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4





all_select=comparison_select_unique | reference_select_unique | other_side_select_unique

pvals_packing=vector(mode="numeric",length=5)
names(pvals_packing)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")

# Direct linear modelling on the simulations for the low-strain G' as before
linmod=lm(Gprime_Pa ~ packing_fraction,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,])

pvals_packing["low_strain_plateau"]=coefficients(summary(linmod))["packing_fraction","Pr(>|t|)"]



normality_pvals["Packing density","G' low plateau"]=shapiro.test(resid(linmod))[["p.value"]]




cat("\n\tReporting 2G-Packing1 (Influence of packing density on the low-deformation G'): Item 9")

# Group sizes for the general linear regression
n_packing=aggregate(Gprime_Pa ~ packing_fraction,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,],FUN=length)
colnames(n_packing)[2]="n"
cat("\n\t\tn per group: ")
n_packing
cat("\n\t\tN total simulations: ")
sum(n_packing$n)


# Shapiro-Wilks on the residuals

cat("\n\t\tNormality testing (linear model)")
normality_pvals["Packing density","G' low plateau"]

# Confidence interval for the association (basically, the proportionality constant relating the change in Young modulus to the expected change in G' value on the low strain plateau )
cat("\n\t\tConfidence interval for the slope coefficient between low-deformation G' and packing fraction")
confint(linmod,"packing_fraction")

# The summary of the linear model provides the parameters that we need
s=summary(linmod)


cat("\n\t\tt value:")
coefficients(s)["packing_fraction","t value"]

cat("\n\t\tDegrees of freedom:")
s[["df"]][2]

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\n\t\tEffect size measure: Adjusted R2")
s[["adj.r.squared"]]

cat("\n\t\tP-value (before multiple testing adjustment")
pvals_packing["low_strain_plateau"]








# Bootstrapping for the values that are derived from the entire strain sweep curves as before
res=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])
pvals_packing["softening_strain"]=res
normality_pvals["Packing density","Softening strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Packing2 (Influence of packing density on the softening strain): Item 10")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction %in% c(1,1.5,2) & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the packing density and the softening strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_packing["softening_strain"]




res=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])
pvals_packing["soft_plateau_strain"]=res
normality_pvals["Packing density","Strain on soft plateau"]=attr(res,"p_shapiro")





res=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])
pvals_packing["soft_plateau_Gprime"]=res
normality_pvals["Packing density","G' on soft plateau"]=attr(res,"p_shapiro")


cat("\n\tReporting 2G-Packing3 (Influence of packing density on the soft plateau G'): Item 11")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction %in% c(1,1.5,2) & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the packing density and the G' on the softening plateau")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_packing["soft_plateau_Gprime"]


res=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_yield_strain[all_select,])
pvals_packing["yield"]=res
normality_pvals["Packing density","Yield strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Packing4 (Influence of packing density on the yield strain): Item 12")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction %in% c(1,1.5,2) & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the packing density and the yield strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_packing["yield"]





# Change in friction coefficient
# Again, analogous, see section on Young modulus
cat("Evaluation of the influence of the friction coefficient\n")
cat("=======================================================\n")

comparison_select=overview_agg$Friction_coefficient %in% c(0.003) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4



comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.003) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.003) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4


pvals_friction=vector(mode="numeric",length=5)
names(pvals_friction)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")


all_select=comparison_select_unique | reference_select_unique

linmod=lm(Gprime_Pa ~ Friction_coefficient,overview_simulation[comparison_select_simulation | reference_select_simulation ,])

pvals_friction["low_strain_plateau"]=coefficients(summary(linmod))["Friction_coefficient","Pr(>|t|)"]
normality_pvals["Friction coefficient","G' low plateau"]=shapiro.test(resid(linmod))[["p.value"]]





cat("\n\tReporting 2G-Friction1 (Influence of the friction coefficient on the low-deformation G'): Item 13")

# Group sizes for the general linear regression
n_friction=aggregate(Gprime_Pa ~ Friction_coefficient,overview_simulation[comparison_select_simulation | reference_select_simulation ,],FUN=length)
colnames(n_friction)[2]="n"
cat("\n\t\tn per group: ")
n_friction
cat("\n\t\tN total simulations: ")
sum(n_friction$n)


# Shapiro-Wilks on the residuals

cat("\n\t\tNormality testing (linear model)")
normality_pvals["Friction coefficient","G' low plateau"]

# Confidence interval for the association (basically, the proportionality constant relating the change in Young modulus to the expected change in G' value on the low strain plateau )
cat("\n\t\tConfidence interval for the slope coefficient between low-deformation G' and friction coefficient")
confint(linmod,"Friction_coefficient")

# The summary of the linear model provides the parameters that we need
s=summary(linmod)


cat("\n\t\tt value:")
coefficients(s)["Friction_coefficient","t value"]

cat("\n\t\tDegrees of freedom:")
s[["df"]][2]

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\n\t\tEffect size measure: Adjusted R2")
s[["adj.r.squared"]]

cat("\n\t\tP-value (before multiple testing adjustment")
pvals_friction["low_strain_plateau"]









res=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])
pvals_friction["softening_strain"]=res
normality_pvals["Friction coefficient","Softening strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Friction2 (Influence of the friction coefficient on the softening strain): Item 14")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient %in% c(0.003,0.01) & overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the friction coefficient and the softening strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_friction["softening_strain"]





res=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])
pvals_friction["soft_plateau_strain"]=res
normality_pvals["Friction coefficient","Strain on soft plateau"]=attr(res,"p_shapiro")

res=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])
pvals_friction["soft_plateau_Gprime"]=res
normality_pvals["Friction coefficient","G' on soft plateau"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Friction3 (Influence of friction coefficient on the soft plateau G'): Item 15")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient %in% c(0.003,0.01) & overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the friction coefficient and the G' on the softening plateau")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_friction["soft_plateau_Gprime"]




res=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_yield_strain[all_select,])
pvals_friction["yield"]=res
normality_pvals["Friction coefficient","Yield strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Friction4 (Influence of the friction coefficient on the yield strain): Item 16")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient %in% c(0.003,0.01) & overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the friction coefficient and the yield strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_friction["yield"]


#plot(predict(linmod),resid(linmod))






# Change in porosity ====================
# once more the same approach
cat("Evaluation of the influence of porosity\n")

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0



comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0






all_select=comparison_select_unique | reference_select_unique

pvals_porosity=vector(mode="numeric",length=5)
names(pvals_porosity)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")


linmod=lm(Gprime_Pa ~ remove_link_fraction,overview_simulation[comparison_select_simulation | reference_select_simulation,])

pvals_porosity["low_strain_plateau"]=coefficients(summary(linmod))["remove_link_fraction","Pr(>|t|)"]

#plot(predict(linmod),resid(linmod))

normality_pvals["Porosity","G' low plateau"]=shapiro.test(resid(linmod))[["p.value"]]








cat("\n\tReporting 2G-Porosity1 (Influence of the porosity on the low-deformation G'): Item 18")

# Group sizes for the general linear regression
n_porosity=aggregate(Gprime_Pa ~ remove_link_fraction,overview_simulation[comparison_select_simulation | reference_select_simulation,],FUN=length)

colnames(n_porosity)[2]="n"
cat("\n\t\tn per group: ")
n_porosity
cat("\n\t\tN total simulations: ")
sum(n_porosity$n)


# Shapiro-Wilks on the residuals

cat("\n\t\tNormality testing (linear model)")
normality_pvals["Porosity","G' low plateau"]

# Confidence interval for the association (basically, the proportionality constant relating the change in Young modulus to the expected change in G' value on the low strain plateau )
cat("\n\t\tConfidence interval for the slope coefficient between low-deformation G' and friction coefficient")
confint(linmod,"remove_link_fraction")

# The summary of the linear model provides the parameters that we need
s=summary(linmod)


cat("\n\t\tt value:")
coefficients(s)["remove_link_fraction","t value"]

cat("\n\t\tDegrees of freedom:")
s[["df"]][2]

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\n\t\tEffect size measure: Adjusted R2")
s[["adj.r.squared"]]

cat("\n\t\tP-value (before multiple testing adjustment")
pvals_porosity["low_strain_plateau"]







res=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])
pvals_porosity["softening_strain"]=res
normality_pvals["Porosity","Softening strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Porosity2 (Influence of the porosity on the softening strain): Item 19")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient ==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction %in% c(0,0.4) & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between link removal fraction and the softening strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_porosity["softening_strain"]




res=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])
pvals_porosity["soft_plateau_strain"]=res
normality_pvals["Porosity","Strain on soft plateau"]=attr(res,"p_shapiro")

res=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])
pvals_porosity["soft_plateau_Gprime"]=res
normality_pvals["Porosity","G' on soft plateau"]=attr(res,"p_shapiro")


cat("\n\tReporting 2G-Porosity3 (Influence of the porosity on the soft plateau G'): Item 20")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient ==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction %in% c(0,0.4) & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")

cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between link removal fraction and the G' on the softening plateau")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_porosity["soft_plateau_Gprime"]


res=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_yield_strain[all_select,])
pvals_porosity["yield"]=res
normality_pvals["Porosity","Yield strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Porosity4 (Influence of the porosity on the yield strain): Item 21")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient ==0.01 & overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & overview_simulation $remove_link_fraction %in% c(0,0.4) & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between link removal fraction and the yield strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_porosity["yield"]




# Change in particle shape (that is, no crosslinks for spherical)
# Same approach, see section on Young modulus
cat("Evaluation of the influence of particle shape\n")

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("uncrosslinked")

comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("uncrosslinked") & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("uncrosslinked")


pvals_shape=vector(mode="numeric",length=5)
names(pvals_shape)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")


all_select=comparison_select_unique | reference_select_unique

linmod=lm(Gprime_Pa ~ Sample_type,overview_simulation[comparison_select_simulation | reference_select_simulation,])

pvals_shape["low_strain_plateau"]=coefficients(summary(linmod))["Sample_typeparticles","Pr(>|t|)"]



#plot(predict(linmod),resid(linmod))

normality_pvals["Shape","G' low plateau"]=shapiro.test(resid(linmod))[["p.value"]]



cat("\n\tReporting 2G-Shape1 (Influence of particle shape on the low-deformation G'): Item 22")

# Group sizes for the general linear regression
n_shape=aggregate(Gprime_Pa ~ Sample_type,overview_simulation[comparison_select_simulation | reference_select_simulation,],FUN=length)

colnames(n_shape)[2]="n"
cat("\n\t\tn per group: ")
n_shape
cat("\n\t\tN total simulations: ")
sum(n_shape$n)


# Shapiro-Wilks on the residuals

cat("\n\t\tNormality testing (linear model)")
normality_pvals["Shape","G' low plateau"]

# Confidence interval for the association (basically, the proportionality constant relating the change in Young modulus to the expected change in G' value on the low strain plateau )
cat("\n\t\tConfidence interval for the slope coefficient between shape (irregular vs. spherical) and low-strain G'")
confint(linmod,"Sample_typeparticles")

# The summary of the linear model provides the parameters that we need
s=summary(linmod)


cat("\n\t\tt value:")
coefficients(s)["Sample_typeparticles","t value"]

cat("\n\t\tDegrees of freedom:")
s[["df"]][2]

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\n\t\tEffect size measure: Adjusted R2")
s[["adj.r.squared"]]

cat("\n\t\tP-value (before multiple testing adjustment")
pvals_shape["low_strain_plateau"]



res=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_mid_softening_strain[all_select,])
pvals_shape["softening_strain"]=res
normality_pvals["Shape","Softening strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Shape2 (Influence of the particle shape on the softening strain): Item 23")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient ==0.01  & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & ((overview_simulation $remove_link_fraction == 0.4 & overview_simulation$Sample_type == "particles") | overview_simulation$Sample_type == "uncrosslinked") & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 )
cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between shape (irregular vs. spherical) and the softening strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_shape["softening_strain"]


res=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_soft_plateau_strain[all_select,])
pvals_shape["soft_plateau_strain"]=res
normality_pvals["Shape","Strain on soft plateau"]=attr(res,"p_shapiro")

res=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_soft_plateau_Gprime[all_select,])
pvals_shape["soft_plateau_Gprime"]=res
normality_pvals["Shape","G' on soft plateau"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Shape3 (Influence of the particle shape on the soft plateau G'): Item 24")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient ==0.01  & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & ((overview_simulation $remove_link_fraction == 0.4 & overview_simulation$Sample_type == "particles") | overview_simulation$Sample_type == "uncrosslinked") & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 )

cat("\n\t\tNormality testing (linear model; no mitigation here since anyways not significant)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between shape (irregular vs. spherical) and the G' on the softening plateau")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_shape["soft_plateau_Gprime"]

res=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_yield_strain[all_select,])
pvals_shape["yield"]=res
normality_pvals["Shape","Yield strain"]=attr(res,"p_shapiro")

cat("\n\tReporting 2G-Shape4 (Influence of the particle shape on the yield strain): Item 25")

cat("\n\t\tn per group: 5 (bootstrapping)")
cat("\n\t\tN total simulations")
sum( overview_simulation$Friction_coefficient ==0.01  & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 & ((overview_simulation $remove_link_fraction == 0.4 & overview_simulation$Sample_type == "particles") | overview_simulation$Sample_type == "uncrosslinked") & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 )

cat("\n\t\tNormality testing (linear model)")
attr(res,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(res,"F")
cat("\n\t\tConfidence interval for the slope coefficient between shape (irregular vs. spherical) and the yield strain")
attr(res,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(res,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(res,"DF1"),attr(res,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
pvals_shape["yield"]




# Assemble the data ============================================

# All the pvalues
pvals=rbind(pvals_Young,pvals_packing,pvals_friction,pvals_porosity,pvals_shape)

# For the manuscript, we restrict ourselves to a subset of output values that can be tuned by the model parameters

colnames(pvals)=c("G' low plateau","Softening strain","Strain on soft plateau","G' on soft plateau","Yield strain")

rownames(pvals)=c("Young modulus","Packing density","Friction coefficient","Porosity","Shape")

# We removed the strain on the soft plateau for better display as none of the physical variables can be used. For reference, the complete set (the statistical conclusions are the same)

pvals_complete=pvals

# restriction to the outcome values of interest
pvals=pvals[,c("G' low plateau","Softening strain","G' on soft plateau","Yield strain")]
# same for the normality
normality_pvals=normality_pvals[,c("G' low plateau","Softening strain","G' on soft plateau","Yield strain")]

# Bonferroni multiple testing correction
pvals_pre_adjustment=pvals
normality_pvals_pre_adjustment=normality_pvals
pvals_complete_pre_adjustment=pvals_complete

pvals[]=p.adjust(pvals,method="bonferroni")
normality_pvals[]=p.adjust(normality_pvals,method="bonferroni")
pvals_complete[]=p.adjust(pvals_complete,method="bonferroni")


# We don't use marginal significance
sig_labs=significance_labels(pvals,levels=c(0.05, 0.01, 0.001),codes=c(
"*", "**", "***"))



cat("\n\nReporting of assembled values")
cat("\nP-values after multiple testing correction\n")

pvals


cat("Significance\n")
sig_labs



# cat("For reference: same table but with strain on soft plateau")

# significance_labels(pvals_complete,levels=c(0.05, 0.01, 0.001),codes=c(
# "*", "**", "***"))


cat("Normality P-values pre-multiple testing correction\n")

normality_pvals_pre_adjustment

cat("Normality P-values after multiple testing correction\n")

normality_pvals


cat("Significance of the normality P-values (not significant means parametric test is OK)\n")
significance_labels(normality_pvals_pre_adjustment,levels=c(0.05, 0.01, 0.001),codes=c(
"*", "**", "***"))

# And finally, plotting of Fig. 2g
# first, the outline rectangle of the table and axis settings
plot(c(0,1,1,0,0),c(0,0,1,1,0),xlim=c(-0.5,1),ylim=c(0,1.5),type="l",xaxt="n",yaxt="n",bty="n",xlab="",ylab="")



# Put the significance values as stars

for(col_index in 1:(dim(pvals)[2])){
    for(row_index in 1:(dim(pvals)[1])){
        if(pvals[row_index,col_index]<=0.05){
            text(x=(col_index-0.5)/(dim(pvals)[2]),y=1-(row_index-0.5)/(dim(pvals)[1]),labels=significance_labels(pvals[row_index,col_index]),cex=2)
        }
    }
}

# Vertical lines
for(col_index in 1:(dim(pvals)[2]-1)){
lines(rep(col_index/dim(pvals)[2],2),c(0,1),type="l")    
}
# Horizontal lines
for(row_index in 1:(dim(pvals)[1]-1)){
    lines(c(0,1),rep(row_index/dim(pvals)[1],2),type="l")    
}


# Put the labels for the columns
for(col_index in 1:(dim(pvals)[2])){
       text(x=(col_index-0.5)/(dim(pvals)[2]),y=1.25,labels=colnames(pvals)[col_index],srt=90)
}


# Put the labels for the rows
for(row_index in 1:(dim(pvals)[1])){
       text(x=-0.25,y=1-(row_index-0.5)/(dim(pvals)[1]),labels=rownames(pvals)[row_index])
}




dev.off()