library(plot.counts)
library(effsize)

# Plot shape parameters for the particles: Here, roundness

# Roundness is 4*Area/pi/(Major axis)^2
# This is a standard shape descriptor in imageJ, see
# https://imagej.nih.gov/ij/docs/guide/146-30.html

load("/data/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda")

# For Figure 3, limit to EPI, Juvederm and Sephacryl S200
# We also measured lab-made irregular non porous CMC particles, 
# these results are mentioned in the text only as they support
# Figure 5 only.

overview_particle_shape=overview_particle_shape[overview_particle_shape$Material %in% c("EPI","Juvederm","Sephacryl S200"),]

overview_particle_shape$Material=factor(as.character(overview_particle_shape$Material),levels=c("EPI","Juvederm","Sephacryl S200"))

# To have in the order from most irregular/porous to spherical
overview_particle_shape$Material=factor(as.character(overview_particle_shape$Material),levels=c("EPI","Juvederm","Sephacryl S200"))

# Aggregate per image analyzed. Subtle changes in exposure and 
# particle density can lead to small systematic biais and so 
# the clustering per image should be taken into account
overview_particle_shape_per_image = aggregate(overview_particle_shape[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=overview_particle_shape[,c("Material","Folder","Image")],FUN=mean)

# To have the numerical values per material
overview_particle_shape_aggregated = aggregate(overview_particle_shape_per_image[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=list(Material=overview_particle_shape_per_image[,c("Material")]),FUN=mean)

# and the standard deviation
overview_particle_shape_aggregated_sd = aggregate(overview_particle_shape_per_image[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=list(Material=overview_particle_shape_per_image[,c("Material")]),FUN=sd)

# Statistics

pvals_roundness=get_t_test_matrix(treatment_factor=overview_particle_shape_per_image$Material, data=overview_particle_shape_per_image$Roundness)[1,]


shapiro_roundness = aggregate(Roundness ~ Material,overview_particle_shape_per_image,FUN=function(x){shapiro.test(x)$p.val} )


# If the shapiro Wilks test for normality indicates departure from normality, use Wilcoxon instead
for(m in names(pvals_roundness))
{
    if(shapiro_roundness[match("EPI", shapiro_roundness$Material),"Roundness"] <= 0.05 |
    shapiro_roundness[match(m, shapiro_roundness$Material),"Roundness"] <= 0.05)
    {
        pvals_roundness[m]=wilcox.test(overview_particle_shape_per_image$Roundness[overview_particle_shape_per_image$Material=="EPI"],overview_particle_shape_per_image$Roundness[overview_particle_shape_per_image$Material==m])$p.val
    }
}



# Bonferroni adjustment

pvals_roundness_Bonferroni=pvals_roundness*(length(pvals_roundness)-1) # Test EPI-EPI does not count
pvals_roundness_Bonferroni[pvals_roundness_Bonferroni>1]=1

# Output statistical values to Console
cat("\nStatistical reporting: Comparison of roundness between materials (Item 93)\n")
cat("Number of particles analysed per material\n")
aggregate(Image ~ Material,overview_particle_shape,FUN=length)

cat("\nNumber of images per material\n")
aggregate(Image ~ Material,overview_particle_shape_per_image,FUN=length)

cat("\nNumber of tests (for Bonferroni correction)\n")
length(pvals_roundness)-1

cat("\nT-test outputs\n")
materials=unique(overview_particle_shape_per_image$Material)
materials_to_test=materials[materials!="EPI"]
for(theTest in materials_to_test)
{
cat("\n",theTest," vs. EPI \n")
print(t.test(overview_particle_shape_per_image$Roundness[overview_particle_shape_per_image$Material==theTest],overview_particle_shape_per_image$Roundness[overview_particle_shape_per_image$Material=="EPI"]))

}

cat("\nEffect size calculated as Cohen's d\n")
materials=unique(overview_particle_shape_per_image$Material)
materials_to_test=materials[materials!="EPI"]
for(theTest in materials_to_test)
{
cat("\n",theTest," vs. EPI \n")
print(cohen.d(overview_particle_shape_per_image$Roundness[overview_particle_shape_per_image$Material==theTest],overview_particle_shape_per_image$Roundness[overview_particle_shape_per_image$Material=="EPI"]))

}






# Output statistical values to Console
cat("\nP-values Roundness, EPI vs.\n")
pvals_roundness
cat("\n\nP-values Roundness, Bonferroni correction EPI vs.\n")
pvals_roundness_Bonferroni

cat("\n\nShapiro-Wilks for roundness: normality for each material")
shapiro_roundness


cat("\n\n\n For Shapiro-Wilks P-values below 0.05, Wilcoxon testing was used, t-tests otherwise")

# Plotting the graphs

pdf("fig_3d.pdf")

xvals=barplot_dots(treatment=overview_particle_shape_per_image$Material,data=overview_particle_shape_per_image[,c("Roundness")],pch=21,cex=2,bg="black",lateral_shift=0.05,y_threshold_for_shifting=0.02,ylab="Roundness",sig_codes=significance_labels(pvals_roundness_Bonferroni),sig.cex=3, main="Roundness evaluation")

lines(c(min(xvals),max(xvals)),rep(particle_shape_roundness_cutoff,2),lty=2)

legend("topleft",legend="Cut off spherical particles",lty=2)

dev.off()




