library(plot.counts)
library(effsize)

# Plot shape parameters for the particles: Solidity

# Solidity is Area/Convex Hull
# This is a standard shape descriptor in imageJ, see
# https://imagej.nih.gov/ij/docs/guide/146-30.html

load("/data/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda")

# For Figure 3, limit to EPI, Juvederm and Sephacryl S200
# We also measured lab-made irregular non porous CMC particles, 
# these results are mentioned in the text only as they support
# Figure 5 only.

overview_particle_shape=overview_particle_shape[overview_particle_shape$Material %in% c("EPI","Juvederm","Sephacryl S200"),]

# To have in the order from most irregular/porous to spherical
overview_particle_shape$Material=factor(as.character(overview_particle_shape$Material),levels=c("EPI","Juvederm","Sephacryl S200"))

# Aggregate per image analyzed. Subtle changes in exposure and 
# particle density can lead to small systematic biais and so 
# the clustering per image should be taken into account
overview_particle_shape_per_image = aggregate(overview_particle_shape[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=overview_particle_shape[,c("Material","Folder","Image")],FUN=mean)

# To have the numerical values per material
overview_particle_shape_aggregated = aggregate(overview_particle_shape_per_image[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=list(Material=overview_particle_shape_per_image[,c("Material")]),FUN=mean)

# and the standard deviation
overview_particle_shape_aggregated_sd = aggregate(overview_particle_shape_per_image[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=list(Material=overview_particle_shape_per_image[,c("Material")]),FUN=sd)

# Statistics



pvals_solidity=get_t_test_matrix(treatment_factor=overview_particle_shape_per_image$Material, data=overview_particle_shape_per_image$Solidity)[1,]


shapiro_solidity = aggregate(Solidity ~ Material,overview_particle_shape_per_image,FUN=function(x){shapiro.test(x)$p.val} )

# If the shapiro Wilks test for normality indicates departure from normality, use Wilcoxon instead

for(m in names(pvals_solidity))
{
    if(shapiro_solidity[match("EPI", shapiro_solidity$Material),"Solidity"] <= 0.05 |
    shapiro_solidity[match(m, shapiro_solidity$Material),"Solidity"] <= 0.05)
    {
        pvals_solidity[m]=wilcox.test(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"],overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material==m])$p.val
    }
}

# Bonferroni adjustment

pvals_solidity_Bonferroni=pvals_solidity*(length(pvals_solidity)-1) # Test EPI-EPI does not count
pvals_solidity_Bonferroni[pvals_solidity_Bonferroni>1]=1

# Output statistical values to Console

cat("\nStatistical reporting: Solidity between different materials (Item 94)\n")
cat("Number of particles analysed per material\n")
aggregate(Image ~ Material,overview_particle_shape,FUN=length)

cat("\nNmber of images per material\n")
aggregate(Image ~ Material,overview_particle_shape_per_image,FUN=length)

cat("\nNumber of tests (for Bonferroni correction)\n")
length(pvals_solidity)-1

cat("\nTest outputs\n")
materials=unique(overview_particle_shape_per_image$Material)
materials_to_test=materials[materials!="EPI"]
for(theTest in materials_to_test)
{
cat("\n",theTest," vs. EPI \n")
if(shapiro_solidity[match("EPI", shapiro_solidity$Material),"Solidity"] > 0.05 &
    shapiro_solidity[match(theTest, shapiro_solidity$Material),"Solidity"] > 0.05)
    {
print(t.test(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material==theTest],overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"]))
    } else {
       print(wilcox.test(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material==theTest],overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"],conf.int = TRUE)) 
    }

}

cat("\nEffect size calculated as Cohen's d (for normal distribution) or Z^2/N for non-parametric testing\n")
materials=unique(overview_particle_shape_per_image$Material)
materials_to_test=materials[materials!="EPI"]
for(theTest in materials_to_test)
{
cat("\n",theTest," vs. EPI \n")
if(shapiro_solidity[match("EPI", shapiro_solidity$Material),"Solidity"] > 0.05 &
    shapiro_solidity[match(theTest, shapiro_solidity$Material),"Solidity"] > 0.05)
    {
print(cohen.d(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material==theTest],overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"]))
    } else {
        w=wilcox.test(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material==theTest],overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])
        Zval=qnorm(w$p.value/2)
        cat("r^2=Z^2/N=",Zval^2/length(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material%in%c(theTest,"EPI")]))
    }
}



cat("\nP-values Solidity, EPI vs.\n")
pvals_solidity
cat("\n\nP-values Solidity, Bonferroni correction EPI vs.\n")
pvals_solidity_Bonferroni

cat("\n\nShapiro-Wilks for solidity: normality for each material")
shapiro_solidity

cat("\n\n\n For Shapiro-Wilks P-values below 0.05, Wilcoxon testing was used, t-tests otherwise")

# Plotting the graphs



pdf("fig_3e.pdf")

xvals=barplot_dots(treatment=overview_particle_shape_per_image$Material,data=overview_particle_shape_per_image[,c("Solidity")],pch=21,cex=2,bg="black",lateral_shift=0.05,y_threshold_for_shifting=0.02,ylab="Solidity",sig_codes=significance_labels(pvals_solidity_Bonferroni),sig.cex=3,main="Solidity evaluation")

lines(c(min(xvals),max(xvals)),rep(particle_shape_solidity_cutoff,2),lty=2)

legend("topleft",legend="Cut off porous particles",lty=2)

dev.off()


