# Figure 3h shows the rheological mastercurves for the EPI and Sephacryl materials. The script needs the data in "stress_sweeps_EPI.rda" and "stress_sweeps_sephacryl_S200.rda"

# Plotting library
library(plot.counts)


# Load the data
load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda")



library(effsize) # For effect size evaluation

# start the graphical device for pdf generation

pdf("fig_3h.pdf")



# The curves take a deep turn down, at too high slope, vertical imaging becomes unrealistic
threshold_horizontal_averaging_EPI=0.1
threshold_horizontal_averaging_sephacryl_S200=0.5


to_use_EPI=stress_sweeps_EPI



# The Sephacryl S200 was measured with a cup geometry, while for the EPI biomaterial, there are also some plate-plate measurements (see Supplementary 10). We should only compare identical geometries
to_use_EPI=to_use_EPI[to_use_EPI$Geometry=="cup",]

to_use_EPI$polymer_conc_mgmL = round(to_use_EPI$polymer_conc_mgmL)



# For normalization, we need to know the characteristic G' value (i.e. the low strain G' plateau value)


summary_properties_EPI = data.frame(polymer_conc_mgmL=sort(unique(to_use_EPI$polymer_conc_mgmL)),Gprime_Pa=NA)

# By concentration
for(ind in 1:(dim(summary_properties_EPI)[1]))
{
    theConc=summary_properties_EPI$polymer_conc_mgmL[ind]
    # For the plateau value, we apply the following criteria
    # 1) Elastic behaviour, G''<0.1*G'
    # 2) Low applied oscillatory stress, tau<2 Pa
    sel_for_Gprime = (to_use_EPI$polymer_conc_mgmL==theConc) & (to_use_EPI$Gprimeprime_Pa/to_use_EPI$Gprime_Pa<0.1)&( to_use_EPI$tau_Pa<2)
    if(any(sel_for_Gprime))
    {
        summary_properties_EPI$Gprime_Pa[ind]=mean(to_use_EPI$Gprime_Pa[sel_for_Gprime])
    }
    
}



# Now we can normalize

to_use_EPI$Gprime_for_normalization=summary_properties_EPI$Gprime_Pa[match(to_use_EPI$polymer_conc_mgmL,summary_properties_EPI$polymer_conc_mgmL)]


to_use_EPI$Gprime_rel = to_use_EPI$Gprime_Pa/to_use_EPI$Gprime_for_normalization

to_use_EPI$Gprimeprime_rel = to_use_EPI$Gprimeprime_Pa/to_use_EPI$Gprime_for_normalization

to_use_EPI$tau_rel = to_use_EPI$tau_Pa/to_use_EPI$Gprime_for_normalization


# Aggregate points with shear stresses in common intervals (logarithmic spacing to align the curves)

to_use_EPI$tau_rel_to_aggregate=exp(1/2*round(2*log(to_use_EPI$tau_rel)))


# Now we can aggregate all the relative points available per interval from all the curves, this gives the
# master curve. Due to technical limitations, not all the curves cover the entire master curve (sensitivity and
# capacity of the rheometer to apply sufficiently small shear)
master_curve_EPI=aggregate(data.frame(Gprime_rel=to_use_EPI$Gprime_rel),by=list(tau_rel = to_use_EPI$tau_rel_to_aggregate),FUN=mean)
master_curve_EPI_sd=aggregate(data.frame(Gprime_rel=to_use_EPI$Gprime_rel),by=list(tau_rel = to_use_EPI$tau_rel_to_aggregate),FUN=sd)


# Get the one-standard deviation curves. These are for illustration, not statistical testing (see below)

horizontal_averaging=data.frame(tau_rel=NA,Gprime_rel=(2:0)/2*threshold_horizontal_averaging_EPI)
horizontal_averaging_sd = horizontal_averaging

spacing=abs(horizontal_averaging$Gprime_rel[2]-horizontal_averaging$Gprime_rel[1])

for(ind in 1:(dim(horizontal_averaging)[1]))
{
    horizontal_averaging$tau_rel[ind] = mean(to_use_EPI$tau_rel[(to_use_EPI$Gprime_rel>horizontal_averaging$Gprime_rel[ind]-spacing/2) & (to_use_EPI$Gprime_rel<=horizontal_averaging$Gprime_rel[ind]+spacing/2)],na.rm=TRUE)
    
    horizontal_averaging_sd$tau_rel[ind] = sd(to_use_EPI$tau_rel[(to_use_EPI$Gprime_rel>horizontal_averaging$Gprime_rel[ind]-spacing/2) & (to_use_EPI$Gprime_rel<=horizontal_averaging$Gprime_rel[ind]+spacing/2)],na.rm=TRUE)
    
}

master_curve_EPI_sd=rbind(master_curve_EPI_sd[master_curve_EPI$Gprime_rel>max(horizontal_averaging$Gprime_rel),],horizontal_averaging_sd)


master_curve_EPI=rbind(master_curve_EPI[master_curve_EPI$Gprime_rel>max(horizontal_averaging$Gprime_rel),],horizontal_averaging)





# Upper and lower curves, one standard deviation away from main curve

horizontal_averaging_upper_curve = horizontal_averaging

horizontal_averaging_upper_curve$tau_rel = horizontal_averaging$tau_rel+horizontal_averaging_sd$tau_rel

horizontal_averaging_lower_curve = horizontal_averaging

horizontal_averaging_lower_curve$tau_rel = horizontal_averaging$tau_rel-horizontal_averaging_sd$tau_rel


upper_curve_EPI = master_curve_EPI[master_curve_EPI$Gprime_rel>max(horizontal_averaging$Gprime_rel),]
upper_curve_EPI$Gprime_rel = (master_curve_EPI$Gprime_rel+master_curve_EPI_sd$Gprime_rel)[master_curve_EPI$Gprime_rel>max(horizontal_averaging$Gprime_rel)]

lower_curve_EPI = master_curve_EPI[master_curve_EPI$Gprime_rel>max(horizontal_averaging$Gprime_rel),]
lower_curve_EPI$Gprime_rel = (master_curve_EPI$Gprime_rel-master_curve_EPI_sd$Gprime_rel)[master_curve_EPI$Gprime_rel>max(horizontal_averaging$Gprime_rel)]

upper_curve_EPI=rbind(upper_curve_EPI,horizontal_averaging_upper_curve)
lower_curve_EPI=rbind(lower_curve_EPI,horizontal_averaging_lower_curve)

master_curve_EPI=master_curve_EPI[master_curve_EPI$tau_rel>=7e-5,]



# Plot the EPI data (master curve and single standard deviation)

plot(x=master_curve_EPI$tau_rel,y=master_curve_EPI$Gprime_rel, log="x",xlab="Relative shear stress Tau/G'0",ylab="Relative Modulus G'/G'0",type="l"
,ylim=c(0,1.2),xlim=c(5e-5,1e-1),main="3h) Master curve",xaxt="n",las=2)

axis(side=1,at=c((5:9)*1e-5,(1:9)*1e-4,(1:9)*1e-3,(1:9)*1e-2,0.1),labels=c(expression(""),rep("",4),"10-4",rep("",8),"10-3",rep("",8),"10-2",rep("",8),"10-1"))


lines(Gprime_rel ~ tau_rel,upper_curve_EPI,col="red",type="l")
lines(Gprime_rel ~ tau_rel,lower_curve_EPI,col="red",type="l")


# From here, same analysis but for Sephacryl S200

# Only take curves which display solid-like behaviour

# In particular, in this set, there is a 27mg/mL curv that should not be used because initially, at 1Pa of shear stress, there was already one measurement with G'' > G', very large chuck amplitudes were then observed making measurement unreliable

to_use_sephacryl_S200=stress_sweeps_sephacryl_S200[stress_sweeps_sephacryl_S200$polymer_conc_mgmL>40,]

to_use_sephacryl_S200$polymer_conc_mgmL = round(to_use_sephacryl_S200$polymer_conc_mgmL)



# For normalization, I need to know the characteristic G' (i.e. the low strain G' plateau value)


summary_properties_sephacryl_S200 = data.frame(file=sort(unique(to_use_sephacryl_S200$file)),Gprime_Pa=NA)


for(ind in 1:(dim(summary_properties_sephacryl_S200)[1]))
{
    
    theFile =summary_properties_sephacryl_S200$file[ind]
    sel_for_Gprime = (to_use_sephacryl_S200$file==theFile & to_use_sephacryl_S200$tau_Pa<2)
    if(any(sel_for_Gprime))
    {
        summary_properties_sephacryl_S200$Gprime_Pa[ind]=(to_use_sephacryl_S200$Gprime_Pa[sel_for_Gprime])[1]
    }
    
   
    
}



to_use_sephacryl_S200$Gprime_for_normalization=summary_properties_sephacryl_S200$Gprime_Pa[match(to_use_sephacryl_S200$file,summary_properties_sephacryl_S200$file)]


to_use_sephacryl_S200$Gprime_rel = to_use_sephacryl_S200$Gprime_Pa/to_use_sephacryl_S200$Gprime_for_normalization

to_use_sephacryl_S200$Gprimeprime_rel = to_use_sephacryl_S200$Gprimeprime_Pa/to_use_sephacryl_S200$Gprime_for_normalization

to_use_sephacryl_S200$tau_rel = to_use_sephacryl_S200$tau_Pa/to_use_sephacryl_S200$Gprime_for_normalization



to_use_sephacryl_S200$tau_rel_to_aggregate=exp(1/2*round(2*log(to_use_sephacryl_S200$tau_rel)))


master_curve_sephacryl_S200=aggregate(data.frame(Gprime_rel=to_use_sephacryl_S200$Gprime_rel),by=list(tau_rel = to_use_sephacryl_S200$tau_rel_to_aggregate),FUN=mean)
master_curve_sephacryl_S200_sd=aggregate(data.frame(Gprime_rel=to_use_sephacryl_S200$Gprime_rel),by=list(tau_rel = to_use_sephacryl_S200$tau_rel_to_aggregate),FUN=sd)

horizontal_averaging=data.frame(tau_rel=NA,Gprime_rel=(2:0)/2*threshold_horizontal_averaging_sephacryl_S200)
horizontal_averaging_sd = horizontal_averaging

spacing=abs(horizontal_averaging$Gprime_rel[2]-horizontal_averaging$Gprime_rel[1])

for(ind in 1:(dim(horizontal_averaging)[1]))
{
    horizontal_averaging$tau_rel[ind] = mean(to_use_sephacryl_S200$tau_rel[(to_use_sephacryl_S200$Gprime_rel>horizontal_averaging$Gprime_rel[ind]-spacing/2) & (to_use_sephacryl_S200$Gprime_rel<=horizontal_averaging$Gprime_rel[ind]+spacing/2)])
    
    horizontal_averaging_sd$tau_rel[ind] = sd(to_use_sephacryl_S200$tau_rel[(to_use_sephacryl_S200$Gprime_rel>horizontal_averaging$Gprime_rel[ind]-spacing/2) & (to_use_sephacryl_S200$Gprime_rel<=horizontal_averaging$Gprime_rel[ind]+spacing/2)])
}


# Upper and lower curves, one standard deviation away from main curve

horizontal_averaging_upper_curve = horizontal_averaging

horizontal_averaging_upper_curve$tau_rel = horizontal_averaging$tau_rel+horizontal_averaging_sd$tau_rel

horizontal_averaging_lower_curve = horizontal_averaging

horizontal_averaging_lower_curve$tau_rel = horizontal_averaging$tau_rel-horizontal_averaging_sd$tau_rel


upper_curve_sephacryl_S200 = master_curve_sephacryl_S200[master_curve_sephacryl_S200$Gprime_rel>max(horizontal_averaging$Gprime_rel),]
upper_curve_sephacryl_S200$Gprime_rel = (master_curve_sephacryl_S200$Gprime_rel+master_curve_sephacryl_S200_sd$Gprime_rel)[master_curve_sephacryl_S200$Gprime_rel>max(horizontal_averaging$Gprime_rel)]

lower_curve_sephacryl_S200 = master_curve_sephacryl_S200[master_curve_sephacryl_S200$Gprime_rel>max(horizontal_averaging$Gprime_rel),]
lower_curve_sephacryl_S200$Gprime_rel = (master_curve_sephacryl_S200$Gprime_rel-master_curve_sephacryl_S200_sd$Gprime_rel)[master_curve_sephacryl_S200$Gprime_rel>max(horizontal_averaging$Gprime_rel)]

upper_curve_sephacryl_S200=rbind(upper_curve_sephacryl_S200,horizontal_averaging_upper_curve)
lower_curve_sephacryl_S200=rbind(lower_curve_sephacryl_S200,horizontal_averaging_lower_curve)


upper_curve_sephacryl_S200=upper_curve_sephacryl_S200[!is.na(upper_curve_sephacryl_S200$Gprime_rel),]
lower_curve_sephacryl_S200=lower_curve_sephacryl_S200[!is.na(lower_curve_sephacryl_S200$Gprime_rel),]




master_curve_sephacryl_S200=rbind(master_curve_sephacryl_S200[master_curve_sephacryl_S200$Gprime_rel>max(horizontal_averaging$Gprime_rel),],horizontal_averaging)

lines(Gprime_rel ~ tau_rel,master_curve_sephacryl_S200,lty=2)
lines(Gprime_rel ~ tau_rel,upper_curve_sephacryl_S200,col="green",type="l")
lines(Gprime_rel ~ tau_rel,lower_curve_sephacryl_S200,col="green",type="l")




legend("bottomleft",legend=c("Elastic porous injectable","    +/- 1 standard deviation","Sephacryl S200","   +/- 1 standard deviation"),col=c("black","red","black","green"),lty=c(1,1,2,1))



# Group size reporting

curves_used_EPI = overview_EPI[overview_EPI$Polymer_concentration_adjustment %in% (unique(stress_sweeps_EPI$Polymer_concentration_adjustment)[1:2]) & overview_EPI$Geometry=="cup",]
cat("Statistical reporting (Item 29)")
cat("\nN curves used EPI")
dim(curves_used_EPI)[1]


curves_used_Sephacryl = overview_sephacryl_S200[overview_sephacryl_S200$polymer_conc_mgmL>=40 & overview_sephacryl_S200$Geometry=="cup",]


cat("N curves used Sephacryl")
dim(curves_used_Sephacryl)[1]





# Statistical testing

# Get EPI Gprime values at defined tau rel points

# Collect these in a dataframe for easier use afterwards, of the structure polymer concentration, Gprime relative, and relative shear stress tau


template=data.frame(polymer_conc_mgmL=sort(unique(to_use_EPI$polymer_conc_mgmL)),Gprime_rel=NA,tau_rel=NA)
tau_rel_points=c(5e-4,1e-3,1e-2,5e-2)

started=FALSE

for(the_tau_rel in tau_rel_points)
{
    template$tau_rel=the_tau_rel
    if(started)
    {
        relative_modulus_EPI=rbind(relative_modulus_EPI,template)
    } else
    {
        relative_modulus_EPI=template
        started=TRUE
    }
    
}



for(theConc in unique(to_use_EPI$polymer_conc_mgmL))
{
    
    current_data=to_use_EPI[to_use_EPI$polymer_conc_mgmL==theConc,]
    if(!(is.na(current_data$Gprime_for_normalization))[1])
    {
        for(the_tau_rel in unique(relative_modulus_EPI$tau_rel))
        {
            
            relative_modulus_EPI$Gprime_rel[relative_modulus_EPI$polymer_conc_mgmL==theConc & relative_modulus_EPI$tau_rel==the_tau_rel]=
            approx(x=log(current_data$tau_rel),y=current_data$Gprime_rel,xout=log(the_tau_rel))$y
            
        }
        
    }
}

# Now we have all the data at the desired tau values for the different polymer concentrations (we do statistics on the polymer concentrations as the curves at different polymer concentrations give rise to the master curves)


# Get Sephacryl Gprime values at defined tau rel points (same approach as for the EPI above)

template=data.frame(polymer_conc_mgmL=sort(unique(to_use_sephacryl_S200$polymer_conc_mgmL)),Gprime_rel=NA,tau_rel=NA)




started=FALSE

for(the_tau_rel in tau_rel_points)
{
    template$tau_rel=the_tau_rel
    if(started)
    {
        relative_modulus_sephacryl_S200=rbind(relative_modulus_sephacryl_S200,template)
    } else
    {
        relative_modulus_sephacryl_S200=template
        started=TRUE
    }
    
}



for(theConc in unique(to_use_sephacryl_S200$polymer_conc_mgmL))
{
    
    current_data=to_use_sephacryl_S200[to_use_sephacryl_S200$polymer_conc_mgmL==theConc,]
    if(!(is.na(current_data$Gprime_for_normalization))[1])
    {
        for(the_tau_rel in unique(relative_modulus_sephacryl_S200$tau_rel))
        {
            
            relative_modulus_sephacryl_S200$Gprime_rel[relative_modulus_sephacryl_S200$polymer_conc_mgmL==theConc & relative_modulus_sephacryl_S200$tau_rel==the_tau_rel]=
            approx(x=log(current_data$tau_rel),y=current_data$Gprime_rel,xout=log(the_tau_rel))$y
            
        }
        
    }
}

# This is the overview table over the statistical tests that we will now fill

statistical_comparison=data.frame(tau_rel=tau_rel_points,t=NA,p_val=NA,p_val_adjusted=NA,df=NA,hedges_g=NA,p_shapiro_wilks_EPI=NA,p_shapiro_wilks_sephacryl_S200=NA,p_shapiro_wilks_residuals=NA,confint_lower=NA,confint_upper=NA)


for(the_tau_rel in statistical_comparison$tau_rel)
{
    EPI_Gprime_rel=relative_modulus_EPI$Gprime_rel[relative_modulus_EPI$tau_rel==the_tau_rel & !is.na(relative_modulus_EPI$Gprime_rel)]
    Sephacryl_S200_Gprime_rel=
    relative_modulus_sephacryl_S200$Gprime_rel[relative_modulus_sephacryl_S200$tau_rel==the_tau_rel & ! is.na(relative_modulus_sephacryl_S200$Gprime_rel)]
    
    t_test=t.test(EPI_Gprime_rel,
    Sephacryl_S200_Gprime_rel)
    statistical_comparison$t[statistical_comparison$tau_rel==the_tau_rel]=t_test[["statistic"]]
    statistical_comparison$df[statistical_comparison$tau_rel==the_tau_rel]=t_test[["parameter"]]
    statistical_comparison$p_val[statistical_comparison$tau_rel==the_tau_rel]=t_test[["p.value"]]
    
    
    
    statistical_comparison$hedges_g[statistical_comparison$tau_rel==the_tau_rel]=cohen.d(
        d=c(EPI_Gprime_rel,Sephacryl_S200_Gprime_rel),
        f=factor(c(rep("EPI",length(EPI_Gprime_rel)),
        rep("Sephacryl",length(Sephacryl_S200_Gprime_rel)))),hedges.correction=TRUE)[["estimate"]]
        
    statistical_comparison$p_shapiro_wilks_EPI[statistical_comparison$tau_rel==the_tau_rel]=shapiro.test(EPI_Gprime_rel)[["p.value"]]
    
    statistical_comparison$p_shapiro_wilks_sephacryl_S200[statistical_comparison$tau_rel==the_tau_rel]=shapiro.test(Sephacryl_S200_Gprime_rel)[["p.value"]]
    
    residuals = c(Sephacryl_S200_Gprime_rel-mean(Sephacryl_S200_Gprime_rel,na.rm=TRUE),EPI_Gprime_rel-mean(EPI_Gprime_rel,na.rm=TRUE))
    
    statistical_comparison$p_shapiro_wilks_residuals[statistical_comparison$tau_rel==the_tau_rel]=shapiro.test(residuals)[["p.value"]]
    
    
    statistical_comparison$confint_lower[statistical_comparison$tau_rel==the_tau_rel]=t_test$conf.int[[1]]
    statistical_comparison$confint_upper[statistical_comparison$tau_rel==the_tau_rel]=t_test$conf.int[[2]]
    
        
    
    
}

statistical_comparison$p_val_adjusted=p.adjust(statistical_comparison$p_val, method="bonferroni")


statistical_comparison


dev.off()




