# Fig. 3m shows the G' curves (as a function of strain) recoverd after a given amount of time. This is assembled from the complete kinetic dataset underpinning Fig. 3j.

# Load the file overview_files_self_healing_kinetics.rda
# This file contains self-healing data as acquired by monitoring recovery of
# G' values after a short period of strong shear (as recommended in Chen, M. H. et al. Methods To Assess Shear-Thinning Hydrogels for Application As Injectable Biomaterials. Acs Biomater Sci Eng 3, 3146-3160, doi:10.1021/acsbiomaterials.7b00734 (2017).)


load("/data/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda")

# Start pdf device for the figure
pdf("fig_3m.pdf")
# =========================================

cat("Statistical reporting: Item 38\n\nn per shear level (same for all time-points)")
n=aggregate(f_Hz ~ Tau_Pa ,overview_self_healing_kinetics,FUN=length)
colnames(n)[colnames(n)=="f_Hz"]="n"
n

# Define when the self-healing starts (i.e. last point of strong shear) so that we aggregate the curves
# correctly

start_point = aggregate(t_s_relative ~overview_index,self_healing_kinetics[self_healing_kinetics$Segment=="shear",],FUN=max)

# Time relative to the exact end point of strong shear for each curve
self_healing_kinetics$t_s_relative=self_healing_kinetics$t_s_relative-start_point$t_s_relative[match(self_healing_kinetics$overview_index,start_point$overview_index)]-5

# The baseline is the last point before strong shear
baseline_Gprime=aggregate(Gprime_Pa ~ overview_index, self_healing_kinetics[self_healing_kinetics$Segment=="baseline",],FUN=function(x){x[length(x)]})

# Insert the baseline information into the overview over the sequential self-healing experiments
overview_self_healing_kinetics$Gprime_Pa_baseline = baseline_Gprime$Gprime_Pa[match(1:(dim(overview_self_healing_kinetics)[1]),baseline_Gprime$overview_index)]


# Recover the G' values at defined time points (15s, 30s, 15min and during shear) and report in the overview over the experiments

# initialize
overview_self_healing_kinetics$Gprime_Pa_15s=0
overview_self_healing_kinetics$Gprime_Pa_30s=0
overview_self_healing_kinetics$Gprime_Pa_15min=0
overview_self_healing_kinetics$Gprime_Pa_shear=0

# Loop through the self-healing experiments (consisting of baseline, shear, recovery)
for(ind in 1:(dim(overview_self_healing_kinetics)[1]))
{
    # get the recovery segment for this experiment
    recovery_segment = self_healing_kinetics[self_healing_kinetics$overview_index==ind & self_healing_kinetics$Segment=="recovery",]
    
    # closes matches to the desired time point since the exact time is not exactly aligned to theory
    ind_15min = which.min(abs(recovery_segment$t_s_relative-15*60))
    ind_15s = which.min(abs(recovery_segment$t_s_relative-15))
    ind_30s = which.min(abs(recovery_segment$t_s_relative-30))
    
    # Get the corresponding G' values
    overview_self_healing_kinetics$Gprime_Pa_15min[ind]=recovery_segment$Gprime_Pa[ind_15min]
    overview_self_healing_kinetics$Gprime_Pa_30s[ind]=recovery_segment$Gprime_Pa[ind_30s]
    overview_self_healing_kinetics$Gprime_Pa_15s[ind]=recovery_segment$Gprime_Pa[ind_15s]
    
    # Get the shear segment of this experiment
    shear_segment = self_healing_kinetics[self_healing_kinetics$overview_index==ind & self_healing_kinetics$Segment=="shear",]
    
    # Shear G' is the last G' of this segment
    overview_self_healing_kinetics$Gprime_Pa_shear[ind]=shear_segment$Gprime_Pa[length(shear_segment$Gprime_Pa)]
    
}

# Now we can aggregate the G' values at the defined timepoints for the different probing shear stresses

overview_self_healing_kinetics_agg=aggregate(overview_self_healing_kinetics[,c("Gprime_Pa_baseline","Gprime_Pa_shear","Gprime_Pa_15s","Gprime_Pa_30s","Gprime_Pa_15min")],by=list(Tau_Pa=overview_self_healing_kinetics$Tau_Pa),FUN=mean,na.rm=TRUE)

overview_self_healing_kinetics_agg_sd=aggregate(overview_self_healing_kinetics[,c("Gprime_Pa_baseline","Gprime_Pa_shear","Gprime_Pa_15s","Gprime_Pa_30s","Gprime_Pa_15min")],by=list(Tau_Pa=overview_self_healing_kinetics$Tau_Pa),FUN=sd,na.rm=TRUE)

overview_self_healing_kinetics_agg_sd[!(overview_self_healing_kinetics_agg_sd$Tau_Pa %in% c(0.2,20)),c("Gprime_Pa_baseline","Gprime_Pa_shear","Gprime_Pa_15s","Gprime_Pa_30s","Gprime_Pa_15min")]=NA




# Start out plotting
plot(overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Gprime_Pa_baseline  , log="x",type="l",cex=2,xlab="Shear stress [Pa]",ylab="G' [Pa]",main="K) Recovery of elasticity",ylim=c(0,3000),pch=24,bg="white",xaxt="n",xlim=c(0.01,100))


axis(side=1,at=c((1:9)*0.1,1:9,(1:9)*10,100),labels=c(expression(0.1),rep("",8),1,rep("",8),10,rep("",8),100),cex.axis=2)

# Errorbars
arrows(x0=overview_self_healing_kinetics_agg$Tau_Pa,
    y0=overview_self_healing_kinetics_agg$Gprime_Pa_baseline-overview_self_healing_kinetics_agg_sd$Gprime_Pa_baseline,
    y1=overview_self_healing_kinetics_agg$Gprime_Pa_baseline+overview_self_healing_kinetics_agg_sd$Gprime_Pa_baseline,angle=90,code=3,len=0.1)


# To have the progressively lighter shades for the advancing timepoints, draw polygons
# Baseline
polygon(x=c(overview_self_healing_kinetics_agg$Tau_Pa[1],overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Tau_Pa[length(overview_self_healing_kinetics_agg$Tau_Pa)],
overview_self_healing_kinetics_agg$Tau_Pa[1]),y=c(0,overview_self_healing_kinetics_agg$Gprime_Pa_baseline,0,
0),col=grey(1))

# 15 min
polygon(x=c(overview_self_healing_kinetics_agg$Tau_Pa[1],overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Tau_Pa[length(overview_self_healing_kinetics_agg$Tau_Pa)],
overview_self_healing_kinetics_agg$Tau_Pa[1]),y=c(0,overview_self_healing_kinetics_agg$Gprime_Pa_15min,0,
0),col=grey(0.85))

# 30s
polygon(x=c(overview_self_healing_kinetics_agg$Tau_Pa[1],overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Tau_Pa[length(overview_self_healing_kinetics_agg$Tau_Pa)],
overview_self_healing_kinetics_agg$Tau_Pa[1]),y=c(0,overview_self_healing_kinetics_agg$Gprime_Pa_30s,0,
0),col=grey(0.65))

# 15s
polygon(x=c(overview_self_healing_kinetics_agg$Tau_Pa[1],overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Tau_Pa[length(overview_self_healing_kinetics_agg$Tau_Pa)],
overview_self_healing_kinetics_agg$Tau_Pa[1]),y=c(0,overview_self_healing_kinetics_agg$Gprime_Pa_15s,0,
0),col=grey(0.5))

# shear
polygon(x=c(overview_self_healing_kinetics_agg$Tau_Pa[1],overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Tau_Pa[length(overview_self_healing_kinetics_agg$Tau_Pa)],
overview_self_healing_kinetics_agg$Tau_Pa[1]),y=c(0,overview_self_healing_kinetics_agg$Gprime_Pa_shear,0,
0),col=grey(0))

# Done with the polygons, redraw the lines with the selected errorbars to have them in front

# baseline
lines(overview_self_healing_kinetics_agg$Tau_Pa,overview_self_healing_kinetics_agg$Gprime_Pa_baseline  , type="l",lwd=1.5)

arrows(x0=overview_self_healing_kinetics_agg$Tau_Pa,
    y0=overview_self_healing_kinetics_agg$Gprime_Pa_baseline-overview_self_healing_kinetics_agg_sd$Gprime_Pa_baseline,
    y1=overview_self_healing_kinetics_agg$Gprime_Pa_baseline+overview_self_healing_kinetics_agg_sd$Gprime_Pa_baseline,code=3,length=0.1,angle=90)


# 15s
lines(overview_self_healing_kinetics_agg$Gprime_Pa_15s,overview_self_healing_kinetics_agg$Gprime_Pa_15s  , type="l",lwd=1.5)

arrows(x0=overview_self_healing_kinetics_agg$Tau_Pa,
y0=overview_self_healing_kinetics_agg$Gprime_Pa_15s-overview_self_healing_kinetics_agg_sd$Gprime_Pa_15s,
y1=overview_self_healing_kinetics_agg$Gprime_Pa_15s+overview_self_healing_kinetics_agg_sd$Gprime_Pa_15s,code=3,length=0.1,angle=90)

# 30s
lines(overview_self_healing_kinetics_agg$Gprime_Pa_30s,overview_self_healing_kinetics_agg$Gprime_Pa_30s  , type="l",lwd=1.5)

arrows(x0=overview_self_healing_kinetics_agg$Tau_Pa,
y0=overview_self_healing_kinetics_agg$Gprime_Pa_30s-overview_self_healing_kinetics_agg_sd$Gprime_Pa_30s,
y1=overview_self_healing_kinetics_agg$Gprime_Pa_30s+overview_self_healing_kinetics_agg_sd$Gprime_Pa_30s,code=3,length=0.1,angle=90)

# 15min

lines(overview_self_healing_kinetics_agg$Gprime_Pa_15min,overview_self_healing_kinetics_agg$Gprime_Pa_15min  , type="l",lwd=1.5)

arrows(x0=overview_self_healing_kinetics_agg$Tau_Pa,
y0=overview_self_healing_kinetics_agg$Gprime_Pa_15min-overview_self_healing_kinetics_agg_sd$Gprime_Pa_15min,
y1=overview_self_healing_kinetics_agg$Gprime_Pa_15min+overview_self_healing_kinetics_agg_sd$Gprime_Pa_15min,code=3,length=0.1,angle=90)



# Put the text labels to identify the curves
text(x=0.08,y=overview_self_healing_kinetics_agg$Gprime_Pa_shear[1],labels=c("0s"),adj=1,cex=2)
text(x=0.08,y=overview_self_healing_kinetics_agg$Gprime_Pa_15s[1],labels=c("15s"),adj=1,cex=2)
text(x=0.08,y=overview_self_healing_kinetics_agg$Gprime_Pa_30s[1],labels=c("30s"),adj=1,cex=2)
text(x=0.08,y=overview_self_healing_kinetics_agg$Gprime_Pa_15min[1],labels=c("15min"),adj=1,cex=2)
text(x=0.08,y=overview_self_healing_kinetics_agg$Gprime_Pa_baseline[1],labels=c("Baseline"),adj=1,cex=2)



dev.off()





