library(plot.counts)
library(effsize)

load("/data/Evaluation/Cell adherence/adherence_assay_OP9.rda")



# The wells are grouped in two: the fraction retained on the gel, vs. the lost one

group_totals = aggregate(overview_adherence_OP9[,c("Cell_number","slope")], by=list(Group=overview_adherence_OP9$Group),FUN=sum)

# Relative cell number: adhered to gel compared to total. This
# depends the least on the actual total number of cells

overview_adherence_OP9$rel_Cell_number = overview_adherence_OP9$Cell_number/overview_adherence_OP9$Group_total


# Consider specifically the part on the gels (this reduces the dataset to one entry). Also, we tested some laminin and matrigel coatings on the same plates, but the datasets are as yet incomplete
# and also irrelevant for this figure

on_gel =overview_adherence_OP9[overview_adherence_OP9$fraction=="on_gel" & overview_adherence_OP9$Coating %in% c("Collagen","None") ,]

# Different experiments have different amounts of initial gel, and also of fluid added, this gives rise to a hydration factor

on_gel$hydration_factor=on_gel$V_hydration_mL/on_gel$Vgel_mL

# When the gels were overhydrated, a more or less important fraction of the cells never has the chance to adhere. Correct for this

on_gel$rel_Cell_number[on_gel$hydration_factor>1]=on_gel$rel_Cell_number[on_gel$hydration_factor>1]*on_gel$hydration_factor[on_gel$hydration_factor>1]

# Aggregate on a per-plate basis (the plates are replicates regarding gel and cell sample preparation, so they should be the basis for statistics, not the individual wells)

on_gel_agg=aggregate(on_gel[,c("Cell_number","rel_Cell_number")],by=on_gel[,c("Coating","Mass_fraction","Plate")], FUN=mean)

# P-values by t-test
pvals_t_test=get_t_test_matrix(on_gel_agg$Mass_fraction, on_gel_agg$rel_Cell_number)[1,]
# with Bonferroni correction (for comparison to 0% collagen)
pvals_t_test_Bonferroni=pvals_t_test*(length(pvals_t_test)-1)
pvals_t_test_Bonferroni[pvals_t_test_Bonferroni>1]=1


# Shapiro-Wilks, validation of normality
overview_collagen_agg_shapiro=aggregate(list(rel_Cell_number=on_gel_agg$rel_Cell_number),by=on_gel_agg[,c("Coating","Mass_fraction")], FUN=function(x){shapiro.test(x)$p.val})

# n: actually used datapoints
overview_collagen_agg_n=aggregate(list(n=on_gel_agg$rel_Cell_number),by=on_gel_agg[,c("Coating","Mass_fraction")], FUN=length)

overview_collagen_agg_n$N=aggregate(list(N=on_gel$rel_Cell_number),by=on_gel[,c("Coating","Mass_fraction")], FUN=length)$N


# Effect size (The nomenclature is a bit confuse, but this is really hedges g as hedges g is cohen's d with some variance correction for unequal variance)
overview_collagen_agg_cohen_d=aggregate(list(rel_Cell_number=on_gel_agg$rel_Cell_number),by=on_gel_agg[,c("Coating","Mass_fraction")], FUN=function(x){cohen.d(x,on_gel_agg$rel_Cell_number[on_gel_agg$Coating=="None"],hedges.correction	
=TRUE)$estimate})

overview_collagen_agg_cohen_d$magnitude=aggregate(list(rel_Cell_number=on_gel_agg$rel_Cell_number),by=on_gel_agg[,c("Coating","Mass_fraction")], FUN=function(x){cohen.d(x,on_gel_agg$rel_Cell_number[on_gel_agg$Coating=="None"],hedges.correction	
=TRUE)$magnitude})$rel_Cell_number



pdf("fig_5h.pdf")

xpos=barplot_dots(treatment=on_gel_agg$Mass_fraction*100,data=on_gel_agg$rel_Cell_number*100,cex=2,pch=21,bg="black",lateral_shift=0.1,y_threshold_for_shifting=2,sig_codes=significance_labels(pvals_t_test_Bonferroni,codes=c("",
"*", "**", "***")),sig.cex=3,xlab="Collagen mass fraction [%]",ylab="Cell adhesion [%]",main="5h Cell adherence")

lines(c(min(xpos),max(xpos)),rep(100,2),type="l",col="red")

dev.off()

# Reporting
cat("\nStatistical reporting: test of cell adhesion against uncoated control (Item 66)")
cat("\n\nSample size: n with aggregation per plate, N primary ample size")
overview_collagen_agg_n


cat("\n\nShapiro-Wilks, per coating group")
overview_collagen_agg_shapiro

cat("\n\nT-test details")
for(theMass_fraction in sort(unique(on_gel_agg$Mass_fraction[on_gel_agg$Mass_fraction>0])))
{
    cat(paste("\nComparing ",theMass_fraction*100,"% collagen vs. 0% collagen"),sep="")
    print(t.test(on_gel_agg$rel_Cell_number[on_gel_agg$Mass_fraction==theMass_fraction],
    on_gel_agg$rel_Cell_number[on_gel_agg$Mass_fraction==0]))
}



colnames(overview_collagen_agg_cohen_d)[colnames(overview_collagen_agg_cohen_d)=="rel_Cell_number"]="Eff. size"
cat("\n\nEffect size (test vs. 0% collagen)")
overview_collagen_agg_cohen_d


cat("\n\nP-values, tested against 0% collagen with Bonferroni correction for 3 tests ")
pvals_t_test_Bonferroni[2:length(pvals_t_test_Bonferroni)]












