library(plot.counts)
library(effsize)

# Plot shape parameters for the particles: Solidity

# Solidity is Area/Convex Hull
# This is a standard shape descriptor in imageJ, see
# https://imagej.nih.gov/ij/docs/guide/146-30.html
# Solidity is low in proper porous objects, but also in very irregular obtject

load("/data/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda")


# For Figure 3, limit to EPI, Juvederm and Sephacryl S200
# We also measured lab-made irregular non porous CMC particles,
# these results are mentioned in the text only as they support
# Figure 5 only.


# Aggregate per image analyzed. Subtle changes in exposure and
# particle density can lead to small systematic biais and so
# the clustering per image should be taken into account
overview_particle_shape_per_image = aggregate(overview_particle_shape[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=overview_particle_shape[,c("Material","Folder","Image")],FUN=mean)

# To have the numerical values per material
overview_particle_shape_aggregated = aggregate(overview_particle_shape_per_image[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=list(Material=overview_particle_shape_per_image[,c("Material")]),FUN=mean)

# and the standard deviation
overview_particle_shape_aggregated_sd = aggregate(overview_particle_shape_per_image[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=list(Material=overview_particle_shape_per_image[,c("Material")]),FUN=sd)

# Statistics

pvals_solidity=get_t_test_matrix(treatment_factor=overview_particle_shape_per_image$Material, data=overview_particle_shape_per_image$Solidity)[1,]
t_vals = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
function(x){t.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$statistic})
w_vals = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
function(x){wilcox.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$statistic})

degrees_of_freedom_t = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=function(x){t.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$parameter})


shapiro_solidity = aggregate(Solidity ~ Material,overview_particle_shape_per_image,FUN=function(x){shapiro.test(x)$p.val} )

confidence_lower_bound_t = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
    function(x){t.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$conf.int[1]})
confidence_upper_bound_t = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
    function(x){t.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$conf.int[2]})
confidence_lower_bound_w = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
    function(x){wilcox.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"],conf.int = TRUE)$conf.int[1]})
confidence_upper_bound_w = aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
    function(x){wilcox.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"],conf.int = TRUE)$conf.int[2]})

cohen_distance=aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
function(x){cohen.d(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$estimate})

r2_from_wilcox=aggregate(overview_particle_shape_per_image$Solidity, by=list(Material=overview_particle_shape_per_image$Material),FUN=
function(x){
    pval=wilcox.test(x,overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])$p.value
    Zval=qnorm(pval/2)
    return(Zval^2/(length(x)+length(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"])))
})

cohen.d(c(1,2,3),c(2,3,4))$estimate

confidence_lower_bound=confidence_lower_bound_t
confidence_upper_bound=confidence_upper_bound_t

confidence_lower_bound$x[shapiro_solidity$Solidity<=0.05]=confidence_lower_bound_w$x[shapiro_solidity$Solidity<=0.05]
confidence_upper_bound$x[shapiro_solidity$Solidity<=0.05]=confidence_upper_bound_w$x[shapiro_solidity$Solidity<=0.05]




# If the shapiro Wilks test for normality indicates departure from normality, use Wilcoxon instead
for(m in names(pvals_solidity))
{
    if(shapiro_solidity[match("EPI", shapiro_solidity$Material),"Solidity"] <= 0.05 |
    shapiro_solidity[match(m, shapiro_solidity$Material),"Solidity"] <= 0.05)
    {
        pvals_solidity[m]=wilcox.test(overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material=="EPI"],overview_particle_shape_per_image$Solidity[overview_particle_shape_per_image$Material==m])$p.val
    }
}



# Bonferroni adjustment

pvals_solidity_Bonferroni=pvals_solidity*(length(pvals_solidity)-1) # Test EPI-EPI does not count
pvals_solidity_Bonferroni[pvals_solidity_Bonferroni>1]=1


# Output statistical values to Console
cat("\nStatistical reporting: Solidity evaluated for different particle types (Item 85)")
cat("\nN: number of particles analyzed = ", dim(overview_particle_shape)[1], ", aggregated per sample or image => n=",dim(overview_particle_shape_per_image)[1] )
cat("\nNumber of groups (materials) = ", length(unique(overview_particle_shape$Material)))
cat("\nBonferroni testing: ",length(pvals_solidity)-1," tests")
cat("\n\nShapiro-Wilks for Solidity: normality for each material")
shapiro_solidity
cat("\n\nConfidence intervals: Delta from EPI to material at hand. Lower bounds:\n")
confidence_lower_bound
cat("\nConfidence intervals: Delta from EPI to material at hand. Upper bounds:\n")
confidence_upper_bound

statistic=t_vals
statistic$x=paste("t=",statistic$x,sep="")
statistic$x[shapiro_solidity$Solidity<=0.05]=paste("W=",w_vals$x,sep="")[shapiro_solidity$Solidity<=0.05]

cat("\n\nStatistic: depends on Shapiro-Wilks value, either t-test (t-value) or Wilcox test (W-value)")
statistic

cat("\n\nDegrees of freedom (t statistics only)")
degrees_of_freedom_t$x[shapiro_solidity$Solidity<=0.05]="NA"
degrees_of_freedom_t

cat("\n\nEffect size: depends on Shapiro-Wilks value, either cohen's d with normality or otherwise r^2 from Z^2/N:")
effect_size=cohen_distance
effect_size$x=paste("Cohen's d=",effect_size$x,sep="")
effect_size$x[shapiro_solidity$Solidity<=0.05]=paste("r2=",r2_from_wilcox$x,sep="")[shapiro_solidity$Solidity<=0.05]
effect_size



cat("\nP-values Solidity, EPI vs.\n")
pvals_solidity
cat("\n\nP-values Solidity, Bonferroni correction EPI vs.\n")
pvals_solidity_Bonferroni



cat("\n\n\n For Shapiro-Wilks P-values below 0.05, Wilcoxon testing was used, t-tests otherwise")

# Plotting the graphs

pdf("Fig_S6b.pdf")

xvals=barplot_dots(treatment=overview_particle_shape_per_image$Material,data=overview_particle_shape_per_image[,c("Solidity")],pch=21,cex=2,bg="black",lateral_shift=0.05,y_threshold_for_shifting=0.02,ylab="Solidity",sig_codes=significance_labels(pvals_solidity_Bonferroni),sig.cex=5,las=2,main="Solidity material collection")




dev.off()




    
