library(plot.counts)
library(boot)


load("/data/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda")


# Aggregate per image analyzed. Subtle changes in exposure and 
# particle density can lead to small systematic biais and so 
# the clustering per image should be taken into account
overview_particle_shape_per_image = aggregate(overview_particle_shape[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=overview_particle_shape[,c("Material","Folder","Image","Design_shape","Design_porosity","polymer")],FUN=mean)

# xy limits for drawing
xlim=c(0.35,1)
ylim=c(0.35,1)


pdf("Fig_S6c.pdf")

pchs=c(21,23,21,23,22,23,21,23,24,25)
names(pchs)=levels(overview_particle_shape_per_image$Material)


plot.new()
plot.window(xlim,ylim)
box(col="black")
Axis(side=1)
Axis(side=2)
title(xlab="Solidity",ylab="Roundness")

col_irreg_porous = "#083045"
col_irreg_non_porous = "#b44336"
col_spherical_non_porous="#f5b908"
col_spherical_porous = "#ffffff"

col_irreg_porous_border = "#083045"
col_irreg_non_porous_border = "#b44336"
col_spherical_non_porous_border="#f5b908"
col_spherical_porous_border = "#aaaaaa"

col_irreg_porous_interior = "#1286a8"
col_irreg_non_porous_interior = "#e3a7a0"
col_spherical_non_porous_interior="#fadc84"
col_spherical_porous_interior = "#dddddd"



cols_border=c(rep(col_irreg_porous_border,2),rep(col_irreg_non_porous_border,3),col_spherical_porous_border,rep(col_spherical_non_porous_border,4))
names(cols_border)=levels(overview_particle_shape_per_image$Material)




cols_interior=c(rep(col_irreg_porous_interior,2),rep(col_irreg_non_porous_interior,3),col_spherical_porous_interior,rep(col_spherical_non_porous_interior,4))
names(cols_interior)=levels(overview_particle_shape_per_image$Material)


for(theMaterial in unique(overview_particle_shape_per_image$Material))
{
    current_data = overview_particle_shape_per_image[overview_particle_shape_per_image$Material==theMaterial,c("Solidity","Roundness")]
    current_data$Solidity = current_data$Solidity
    current_data$Roundness = current_data$Roundness
    
    var_cov=cov(current_data)
    ev = eigen(var_cov)
    mean_Solidity = mean(current_data$Solidity)
    mean_Roundness = mean(current_data$Roundness)
    
    angle_values=seq(from=0,to=2*pi,length.out=100)
    
    major_axis_contribution_x=ev$vectors[1,1]*sqrt(ev$values[1])*cos(angle_values)
    major_axis_contribution_y=ev$vectors[2,1]*sqrt(ev$values[1])*cos(angle_values)
    
    minor_axis_contribution_x=ev$vectors[1,2]*sqrt(ev$values[2])*sin(angle_values)
    minor_axis_contribution_y=ev$vectors[2,2]*sqrt(ev$values[2])*sin(angle_values)
    
    col_border=cols_border[theMaterial]
    col_interior=cols_interior[theMaterial]
    
    polygon(mean_Solidity+major_axis_contribution_x+minor_axis_contribution_x,
    mean_Roundness+major_axis_contribution_y+minor_axis_contribution_y,border=col_border,col=col_interior,lwd=3)
    
    
}


plot_counts(overview_particle_shape_per_image$Solidity, overview_particle_shape_per_image$Roundness, groups=overview_particle_shape_per_image$Material,type="p",cex=3.5,ylim=ylim,xlim=xlim,
group_order=levels(overview_particle_shape_per_image$Material),pch=pchs,col="black",bg=c(rep(col_irreg_porous,2),rep(col_irreg_non_porous,3),col_spherical_porous,rep(col_spherical_non_porous,4)),
plot.new=FALSE,lwd=3)

# Cutoff lines, available from the rda file
lines(rep(particle_shape_solidity_cutoff,2),ylim,lty=2,lwd=2)
lines(xlim,rep(particle_shape_roundness_cutoff,2),lty=2,lwd=2)


# Statistical analysis of the cutoff lines
# This is the percentile function to get the cutoff by equality of error rates
# of known positive and negative populations


N_Bonferroni = 2 # We are doing two tests, one for each cutoff

get_fraction_smaller_extrapolated<-function(x,vals)
{
    sort_vals=sort(vals)
    m=mean(vals)
    ret=x
    for(ind in 1:length(x))
    {
    n_smaller=sum(sort_vals<x[ind])
    if(n_smaller>0 & n_smaller<length(sort_vals))
    {
        # interpolate
        
        ret[ind]=n_smaller+(x[ind]-sort_vals[n_smaller])/(sort_vals[n_smaller+1]-sort_vals[n_smaller])
    } else {
        if(n_smaller==0) # this means we are below the first value
        {
           # at the mininum value in vals, ret should be 1, extrapolate with exp(-x2/2sd)
           
           ret[ind]=exp(-((x[ind]-m)/sd(vals))^2/2)/exp(-((sort_vals[1]-m)/sd(vals))^2/2)
           
        } else {
            ret[ind]=n_smaller +1-exp(-((x[ind]-m)/sd(vals))^2/2)/exp(-((sort_vals[length(sort_vals)]-m)/sd(vals))^2/2)
            
        }
    }
    
    }
    ret=ret/(length(sort_vals)+1)
    return(ret)
}


# Specifically for the solidity. This conforms to the formalism of the boot library
# used for bootstrapping. The idx is a TRUE/FALSE vector used for the bootstrapping
# samples

cutoff.solidity <- function(data, idx)
{
  df <- data[idx, ]
  
  solidity_quantile_delta<-function(x){get_fraction_smaller_extrapolated(x,df$Solidity[df$Design_porosity==0])-(1-get_fraction_smaller_extrapolated(x,df$Solidity[df$Design_porosity==1]))}


  solidity_cutoff=uniroot(solidity_quantile_delta,c(0,1))$root
  
  return(solidity_cutoff)
  
  
}




# Same for roundness

cutoff.roundness <- function(data, idx)
{
  df <- data[idx, ]
  
  roundness_quantile_delta<-function(x){get_fraction_smaller_extrapolated(x,df$Roundness[df$Design_shape=="spherical"])-(1-get_fraction_smaller_extrapolated(x,df$Roundness[df$Design_shape=="irregular"]))}

  roundness_cutoff=uniroot(roundness_quantile_delta,c(0,1))$root
  
  return(roundness_cutoff)
  
  
}



# Reporting
overview_particle_shape_per_image$shape_classification=as.numeric(overview_particle_shape_per_image$Roundness<particle_shape_roundness_cutoff)
overview_particle_shape_per_image$porosity_classification=as.numeric(overview_particle_shape_per_image$Solidity<particle_shape_solidity_cutoff)


cat("\n\n\nReporting roundness")
cat("\nDistinct particles analyzed N=",dim(overview_particle_shape)[1])
cat("\nfrom n=",dim(overview_particle_shape_per_image)[1]," imaged samples or published images")

w=wilcox.test(shape_classification ~ Design_shape,overview_particle_shape_per_image)

P_wilcox=w$p.value

# First get Z value from P value (two-sided)
Z_wilcox=-qnorm(P_wilcox/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/(dim(overview_particle_shape_per_image)[1])

cat("\nEffect size from Z^2/N: r2=",r2, "(remark: actually all images classified correctly, so this is should by definition be r2=1)")

cat("\nWilcoxon test")

w

cat("\nWilcoxon test, numerical P-value = ",w$p.value,", after Bonferroni = ",w$p.value*N_Bonferroni)


bootstrap_roundness <- boot(overview_particle_shape_per_image, cutoff.roundness, R = 1000,strata=overview_particle_shape_per_image$Material)

boot.ci(boot.out = bootstrap_roundness,
        type = c("norm"))

cat("\n\n\nReporting solidity")
cat("\nDistinct particles analyzed N=",dim(overview_particle_shape)[1])
cat("\nfrom n=",dim(overview_particle_shape_per_image)[1]," imaged samples or published images")


w=wilcox.test(1-porosity_classification ~ Design_porosity,overview_particle_shape_per_image)
P_wilcox=w$p.value

# First get Z value from P value (two-sided)
Z_wilcox=-qnorm(P_wilcox/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/(dim(overview_particle_shape_per_image)[1])

cat("\nEffect size from Z^2/N: r2=",r2)

w
cat("\nWilcoxon test, numerical P-value = ",w$p.value,", after Bonferroni = ",w$p.value*N_Bonferroni)




bootstrap_solidity <- boot(overview_particle_shape_per_image, cutoff.solidity, R = 1000,strata=overview_particle_shape_per_image$Material)

boot.ci(boot.out = bootstrap_solidity,
        type = c("norm"))
cat("\nFor effect size: adjusted R2 from linear model")
summary(lm(porosity_classification ~ Design_porosity, overview_particle_shape_per_image))

# Estimate confidence intervals on the cutoff values (via bootstrap library boot)

legend("bottomleft",legend=levels(overview_particle_shape_per_image$Material),pch=pchs,col="black",pt.bg=c(rep(col_irreg_porous,2),rep(col_irreg_non_porous,3),col_spherical_porous,rep(col_spherical_non_porous,4)))


dev.off()


# P-value

# Porosity

