# This file reads the cell adherence quantification. This data
# was obtained with Alamar Blue cell number quantification both on the material and in the flow through after washing

# The script reads the Excel file "Adherence_assay_overview run1.xlsx" (in folder "/data/Raw/Cell adherence") and
# estimates the cell numbers from linear fitting and the calibration curves for each plate

# The experimental data is largely about OP9 adhesion. For practical
# reasons, one plate also has HFF data, but this is not exploited further here

library(readxl)

root_folder="/data/Raw/Cell adherence"

setwd(root_folder)

# First: Read the calibration curves per plate

overview_calibration_adherence = as.data.frame(read_excel("Adherence_assay_overview run1.xlsx",sheet="calibration_wells"))


readings_alamar_blue_calibration = as.data.frame(read_excel("Adherence_assay_overview run1.xlsx",sheet="calibration_readings"))

overview_calibration_adherence$slope=NA


# For each well for the various calibration curves (i.e. one per plate), obtain the slope by linear regression. These are kinetics measurements, and the steeper the slope, the faster the Alamar Blue conversion. In the calibration measurements, the cell number seeded is known (2D seeding).

# The aim here is to establish per plate (or, for practical reasons, per plate and cell type since in some experiments we had two cell types, see below) a linear relation between 
# the slope in the kinetics experiments and the cell number
# Later on, this information can be used to calculate back the
# cell number

for(ind in 1:(dim(overview_calibration_adherence)[1]))
{
    info=overview_calibration_adherence[ind,]
    current_data = readings_alamar_blue_calibration[readings_alamar_blue_calibration$Plate==info$Plate & readings_alamar_blue_calibration$Well==info$Well,]
    
    data_regression = current_data[current_data$Time_s >= info$Regression_start_s &  current_data$Time_s <= info$Regression_stop_s, ]
    
    linmod=lm(Fluorescence ~ Time_s, data_regression)
    
    overview_calibration_adherence$slope[ind] = coefficients(linmod)[["Time_s"]]
    
    
}

# In the dataset, there is mainly OP9 measurements, which we use,
# but due to common use of plates with other experiments, there is also some HFF data. We only need the OP9 data, but this nevertheless means we need to make sure that calibration is handled separately for the two cell types

calibration_constants_Alamar_Blue = aggregate(Well ~ Plate + Cell_type,overview_calibration_adherence,FUN=length)
calibration_constants_Alamar_Blue$a = NA
calibration_constants_Alamar_Blue$b = NA

for(ind in 1:dim(calibration_constants_Alamar_Blue)[1])
{
    linmod = lm(slope ~ Cell_number, overview_calibration_adherence[overview_calibration_adherence$Plate==calibration_constants_Alamar_Blue$Plate[ind] & overview_calibration_adherence$Cell_type==calibration_constants_Alamar_Blue$Cell_type[ind],]  )
    calibration_constants_Alamar_Blue$b[ind]=coefficients(linmod)[["(Intercept)"]]
    calibration_constants_Alamar_Blue$a[ind]=coefficients(linmod)[["Cell_number"]]
    
    
}


overview_adherence_OP9 =as.data.frame(read_excel("Adherence_assay_overview run1.xlsx",sheet="OP9_wells"))
readings_adherence_OP9 = as.data.frame(read_excel("Adherence_assay_overview run1.xlsx",sheet="OP9_readings"))

overview_adherence_OP9$Cell_number = NA
for(ind in 1:(dim(overview_adherence_OP9)[1]))
{
    info=overview_adherence_OP9[ind,]
    current_data = readings_adherence_OP9[readings_adherence_OP9$Plate==info$Plate & readings_adherence_OP9$Well==info$Well,]
    
    data_regression = current_data[current_data$Time_s >= info$Regression_start_s &  current_data$Time_s <= info$Regression_stop_s, ]
    
    linmod=lm(Fluorescence ~ Time_s, data_regression)
    
    overview_adherence_OP9$slope[ind] = coefficients(linmod)[["Time_s"]]
    
    a = calibration_constants_Alamar_Blue$a[calibration_constants_Alamar_Blue$Plate==info$Plate & calibration_constants_Alamar_Blue$Cell_type==info$Cell_type]
    b = calibration_constants_Alamar_Blue$b[calibration_constants_Alamar_Blue$Plate==info$Plate & calibration_constants_Alamar_Blue$Cell_type==info$Cell_type]
    
    overview_adherence_OP9$Cell_number[ind]=(overview_adherence_OP9$slope[ind]-b)/a
    
    
    
    
    
    
}

# Physically, we cannot have a negative cell number
#overview_adherence_OP9$Cell_number[overview_adherence_OP9$Cell_number<0]=0


group_totals = aggregate(overview_adherence_OP9[,c("Cell_number","slope")], by=list(Group=overview_adherence_OP9$Group),FUN=sum)

group_N_lost = aggregate(Cell_number ~ Group, overview_adherence_OP9[overview_adherence_OP9$fraction=="lost",],FUN=mean)

overview_adherence_OP9$Group_total = group_totals$Cell_number[match(overview_adherence_OP9$Group,group_totals$Group)]

# Exclude groups where we could detect no cells (there was actually just one, which is probably a pipetting error)

overview_adherence_OP9=overview_adherence_OP9[overview_adherence_OP9$Group_total>0,]


# Limit evaluation to OP9, the HFF measurements are not part of the figure and are incidentally on one plate.

overview_adherence_OP9=overview_adherence_OP9[overview_adherence_OP9$Cell_type=="OP9",]


# Same thing for the readings; the cell type information here is not given directly but can be found via the wells; retain only the wells and plates that are still in the overview_adherence_OP9 variable

wells_ID_OP9 = paste(overview_adherence_OP9$Plate,overview_adherence_OP9$Well)

readings_adherence_OP9=readings_adherence_OP9[paste(readings_adherence_OP9$Plate,readings_adherence_OP9$Well) %in% wells_ID_OP9, ]

# Calibration also, retain only OP9 data

calibration_constants_Alamar_Blue=calibration_constants_Alamar_Blue[calibration_constants_Alamar_Blue$Cell_type=="OP9",]

overview_calibration_adherence=overview_calibration_adherence[overview_calibration_adherence$Cell_type=="OP9",]


save(file="/results/Evaluation/Cell adherence/adherence_assay_run1.rda",list=c("overview_adherence_OP9","readings_adherence_OP9","calibration_constants_Alamar_Blue","overview_calibration_adherence","root_folder"))































